/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/************ Begin %include sections from the grammar ************************/
#line 40 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"

// Allocates a new AST node off the parse state's arena.
#define NEW_AST_NODE(type,name,tok) \
	ZCC_##type *name = static_cast<ZCC_##type *>(stat->InitNode(sizeof(ZCC_##type), AST_##type)); \
	SetNodeLine(name, tok)

static void SetNodeLine(ZCC_TreeNode *name, ZCCToken &tok)
{
	name->SourceLoc = tok.SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, ZCC_TreeNode *node)
{
	if (name == nullptr || node == nullptr)
	{
		I_Error("Fatal parse error");
	}
	name->SourceLoc = node->SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, int line)
{
	name->SourceLoc = line;
}

// If a is non-null, appends b to a. Otherwise, sets a to b.
#define SAFE_APPEND(a,b) \
	if (a == NULL) a = b; else AppendTreeNodeSibling(a, b);

#define UNARY_EXPR(X,T) NEW_AST_NODE(ExprUnary, expr1, X); expr1->Operation = T; expr1->Operand = X; expr1->Type = NULL
#define BINARY_EXPR(X,Y,T) NEW_AST_NODE(ExprBinary, expr2, X); expr2->Operation = T; expr2->Type = NULL; expr2->Left = X; expr2->Right = Y

#define NEW_INTCONST_NODE(name,type,val,tok) \
	NEW_AST_NODE(ExprConstant, name, tok); \
	name->Operation = PEX_ConstValue; \
	name->Type = type; \
	name->IntVal = val

	struct ClassFlagsBlock {
		VM_UWORD Flags;
		ZCC_Identifier *Replaces;
		VersionInfo Version;
	};

	struct StateOpts {
		ZCC_Expression *Offset;
		ZCC_ExprConstant *Lights;
		bool Bright;
		bool Fast;
		bool Slow;
		bool NoDelay;
		bool CanRaise;

		void Zero() {
			Offset = nullptr;
			Lights = nullptr;
			Bright = false;
			Fast = false;
			Slow = false;
			NoDelay = false;
			CanRaise = false;
		}
	};

	struct VarOrFun
	{
		ZCC_VarName *VarNames;
		ZCC_FuncParamDecl *FuncParams;
		ZCC_CompoundStmt *FuncBody;
		ENamedName FuncName;
		int FuncFlags;
		int SourceLoc;
	};
#line 111 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next section is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    ZCCParseTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is ZCCParseTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ZCCParseARG_SDECL     A static variable declaration for the %extra_argument
**    ZCCParseARG_PDECL     A parameter declaration for the %extra_argument
**    ZCCParseARG_STORE     Code to store %extra_argument into yypParser
**    ZCCParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 264
#define YYACTIONTYPE unsigned short int
#define ZCCParseTOKENTYPE  ZCCToken 
typedef union {
  int yyinit;
  ZCCParseTOKENTYPE yy0;
  ZCC_Type * yy6;
  ZCC_FuncParm * yy28;
  VarOrFun yy34;
  ZCC_Identifier * yy35;
  ClassFlagsBlock yy37;
  ZCC_TreeNode * yy38;
  ZCC_BasicType * yy42;
  ZCC_MixinDef * yy48;
  ZCC_FlagDef * yy73;
  ZCC_Expression * yy138;
  ZCC_DeclFlags * yy139;
  ZCC_StaticArrayStatement * yy152;
  ZCC_CaseStmt * yy164;
  ZCC_IfStmt * yy167;
  ZCC_Statement * yy181;
  ZCC_Default * yy205;
  ZCC_PropertyStmt * yy213;
  ZCC_ExprConstant * yy237;
  ZCC_Declarator * yy243;
  ZCC_Enum * yy245;
  ZCC_CompoundStmt * yy261;
  ZCC_Struct * yy262;
  ZCC_StatePart * yy272;
  ZCC_VarName * yy273;
  ZCC_States * yy276;
  ZCC_VarInit * yy299;
  ZCC_ConstantDef * yy307;
  ZCC_FlagStmt * yy380;
  ZCC_Property * yy387;
  ZCC_LocalVarStmt * yy388;
  ZCC_Class * yy414;
  ZCC_ExpressionStmt * yy420;
  StateOpts yy424;
  ZCC_FuncParamDecl * yy433;
  ZCC_AssignStmt * yy453;
  ZCC_ExprFuncCall * yy519;
  ZCC_MixinStmt * yy523;
  int yy527;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 0
#endif
#define ZCCParseARG_SDECL  ZCCParseState *stat ;
#define ZCCParseARG_PDECL , ZCCParseState *stat 
#define ZCCParseARG_FETCH  ZCCParseState *stat  = yypParser->stat 
#define ZCCParseARG_STORE yypParser->stat  = stat 
#define YYERRORSYMBOL 156
#define YYERRSYMDT yy527
#define YYFALLBACK 1
#define YYNSTATE             383
#define YYNRULE              367
#define YY_MAX_SHIFT         382
#define YY_MIN_SHIFTREDUCE   645
#define YY_MAX_SHIFTREDUCE   1011
#define YY_MIN_REDUCE        1012
#define YY_MAX_REDUCE        1378
#define YY_ERROR_ACTION      1379
#define YY_ACCEPT_ACTION     1380
#define YY_NO_ACTION         1381
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (2754)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   111,  110,  647,  649,  650,  651,  652,  653,  654,  108,
 /*    10 */   109,  157,   31,   34,  134,  798,  935,  750,  168,  850,
 /*    20 */   156,  333,  737,  738,  739,  167,  798,  274,  926,  119,
 /*    30 */   308,  796,    2,  949,  157,    2,   24,  928,  716,  809,
 /*    40 */   798,  810,  123,  156,  799,  812,  132,  132,  768,  862,
 /*    50 */   809,  798,  810,  123,  796,  273,  337,  782,  783,  784,
 /*    60 */   785,  786,  787,  788,  789,  790,  791,  792,  793,  794,
 /*    70 */   795,  797,  348,  341,  736,  342,  338,  113,   38,  268,
 /*    80 */   782,  783,  784,  785,  786,  787,  788,  789,  790,  791,
 /*    90 */   792,  793,  794,  795,  797,  348,  341,  286,  342,  338,
 /*   100 */   711,  107,  106,  105,  104,  929,  930,  931,  932,  933,
 /*   110 */   934,   42,  319,  318,   30,    9,  314,  958,  959,  310,
 /*   120 */   112,  309,   50,   77,   90,   89,   88,   98,  101,   96,
 /*   130 */    95,   94,   92,   91,   93,  111,  110,  648,  159,  350,
 /*   140 */   159,   60, 1380,   16,  108,  109,  157,   31,   34,   38,
 /*   150 */   677,  935,  153,  153,  775,  156,  333,  194,  361,  680,
 /*   160 */   679,  683,   93,  926,  670,  308,  796,    2,  950,   60,
 /*   170 */   676,  771,  928,  671,  672,  678,  684,  685,  681,  682,
 /*   180 */   686,  854,   41,  324,  862,  782,  783,  784,  785,  786,
 /*   190 */   787,  329,  782,  783,  784,  785,  786,  787,  788,  789,
 /*   200 */   790,  791,  792,  793,  794,  795,  797,  348,  341,  349,
 /*   210 */   342,  338,   75,   76,   77,   90,   89,   88,   98,  101,
 /*   220 */    96,   95,   94,   92,   91,   93,   15,  231,  194,  863,
 /*   230 */   922,  922,   60,  312,  192,  361,  107,  106,  105,  104,
 /*   240 */   929,  930,  931,  932,  933,  934,   42,  319,  318,   30,
 /*   250 */     9,  314,  958,  959,  310, 1218,  309,   50,   98,  101,
 /*   260 */    96,   95,   94,   92,   91,   93,  306,  306,  853,  798,
 /*   270 */   111,  110,   60,   96,   95,   94,   92,   91,   93,  108,
 /*   280 */   109,  157,   31,   34,  798,   60,  935,  154,  154,  117,
 /*   290 */   156,  333,  747,  809,  798,  810,  123,  118,  926,  339,
 /*   300 */   308,  796,    2,  852,  231,  192,  863,  928,  809,  798,
 /*   310 */   810,  123,  335,  114,  335, 1067,  817,  817, 1353,  862,
 /*   320 */    43,  808,  364,  352,  824,  364,  352,  782,  783,  784,
 /*   330 */   785,  786,  787,  788,  789,  790,  791,  792,  793,  794,
 /*   340 */   795,  797,  348,  341,  232,  342,  338,  710,   76,   77,
 /*   350 */    90,   89,   88,   98,  101,   96,   95,   94,   92,   91,
 /*   360 */    93, 1012,  334,  958,  959,   38,  376,   60,  302,  302,
 /*   370 */    41,  107,  106,  105,  104,  929,  930,  931,  932,  933,
 /*   380 */   934,   42,  319,  318,   30,    9,  314,  958,  959,  310,
 /*   390 */   157,  309,   50,   42,  745,  798,   42,  377,  375,  156,
 /*   400 */   799,  842,  830,  844,  845,  817,  293,   44,  305,  980,
 /*   410 */   796,  746,  163,  233,  267,  171,  315,  232,  846,  809,
 /*   420 */   798,  810,  123,  780,   55,  340,  129,  740,  261,  818,
 /*   430 */   150,  166,  366,  798,  364,  352,  782,  783,  784,  785,
 /*   440 */   786,  787,  788,  789,  790,  791,  792,  793,  794,  795,
 /*   450 */   797,  348,  347,   38,  342,  338,  813,  809,  798,  810,
 /*   460 */   301,  815,  149,  297,  831,  832,  833,  834,  835,  836,
 /*   470 */   837,  839,  840,  841,  843,  847,   72,   69,   68,   67,
 /*   480 */    71,   70,   66,   65,   63,   62,   61,   64,   59,   47,
 /*   490 */    73,   74,   80,   79,   78,   86,   85,   84,   83,   82,
 /*   500 */    81,   87,   75,   76,   77,   90,   89,   88,   98,  101,
 /*   510 */    96,   95,   94,   92,   91,   93,  729,  941,  304,   55,
 /*   520 */   280,  298,   60,  948,   55,   99,  238,  741,  742,  743,
 /*   530 */   744,  131,  758,  731,  951,  190,  361,  865,  657,   72,
 /*   540 */    69,   68,   67,   71,   70,   66,   65,   63,   62,   61,
 /*   550 */    64,   59,  669,   73,   74,   80,   79,   78,   86,   85,
 /*   560 */    84,   83,   82,   81,   87,   75,   76,   77,   90,   89,
 /*   570 */    88,   98,  101,   96,   95,   94,   92,   91,   93,  358,
 /*   580 */   346,  111,  110,  241,  307,   60,   32,   55,  100,  361,
 /*   590 */   108,  109,  157,   31,   55,   55,  173,  361,    8,  262,
 /*   600 */   866,  156,  333,  976,  703,  231,  190,  863,  234,  926,
 /*   610 */   977,  320,  796,  266,  704,  705,   55,  135,  928,   90,
 /*   620 */    89,   88,   98,  101,   96,   95,   94,   92,   91,   93,
 /*   630 */   862,  345,  325,   29,  706,  165,   60,  702,  782,  783,
 /*   640 */   784,  785,  786,  787,  788,  789,  790,  791,  792,  793,
 /*   650 */   794,  795,  797,  348,  341,   19,  342,  338,  231,  880,
 /*   660 */   863,   24,  194,  361,  269,  270,  231,  173,  863,  103,
 /*   670 */   772,  776,  777,  868,  663,  664,  665,  666,  136,  265,
 /*   680 */    15,  128,  107,  106,  105,  104,  929,  930,  931,  932,
 /*   690 */   933,  934,   72,   69,   68,   67,   71,   70,   66,   65,
 /*   700 */    63,   62,   61,   64,   59,  236,   73,   74,   80,   79,
 /*   710 */    78,   86,   85,   84,   83,   82,   81,   87,   75,   76,
 /*   720 */    77,   90,   89,   88,   98,  101,   96,   95,   94,   92,
 /*   730 */    91,   93,  231,  194,  863,  236,  236,  130,   60,  766,
 /*   740 */    72,   69,   68,   67,   71,   70,   66,   65,   63,   62,
 /*   750 */    61,   64,   59,  757,   73,   74,   80,   79,   78,   86,
 /*   760 */    85,   84,   83,   82,   81,   87,   75,   76,   77,   90,
 /*   770 */    89,   88,   98,  101,   96,   95,   94,   92,   91,   93,
 /*   780 */   941,  277,  759,  237,  169,  148,   60,  982,  693,   45,
 /*   790 */   294,   72,   69,   68,   67,   71,   70,   66,   65,   63,
 /*   800 */    62,   61,   64,   59,  969,   73,   74,   80,   79,   78,
 /*   810 */    86,   85,   84,   83,   82,   81,   87,   75,   76,   77,
 /*   820 */    90,   89,   88,   98,  101,   96,   95,   94,   92,   91,
 /*   830 */    93,  295,  732,  239,  825,  822,  120,   60,  979,   72,
 /*   840 */    69,   68,   67,   71,   70,   66,   65,   63,   62,   61,
 /*   850 */    64,   59,  849,   73,   74,   80,   79,   78,   86,   85,
 /*   860 */    84,   83,   82,   81,   87,   75,   76,   77,   90,   89,
 /*   870 */    88,   98,  101,   96,   95,   94,   92,   91,   93,  116,
 /*   880 */   250,  155,  806,  343,  712,   60,  158,   72,   69,   68,
 /*   890 */    67,   71,   70,   66,   65,   63,   62,   61,   64,   59,
 /*   900 */     5,   73,   74,   80,   79,   78,   86,   85,   84,   83,
 /*   910 */    82,   81,   87,   75,   76,   77,   90,   89,   88,   98,
 /*   920 */   101,   96,   95,   94,   92,   91,   93,  989,  708,  127,
 /*   930 */   351,  692,  926,   60,  382,   72,   69,   68,   67,   71,
 /*   940 */    70,   66,   65,   63,   62,   61,   64,   59,    6,   73,
 /*   950 */    74,   80,   79,   78,   86,   85,   84,   83,   82,   81,
 /*   960 */    87,   75,   76,   77,   90,   89,   88,   98,  101,   96,
 /*   970 */    95,   94,   92,   91,   93,   14,  229,   12,  275,  276,
 /*   980 */   283,   60,  230,   72,   69,   68,   67,   71,   70,   66,
 /*   990 */    65,   63,   62,   61,   64,   59,  956,   73,   74,   80,
 /*  1000 */    79,   78,   86,   85,   84,   83,   82,   81,   87,   75,
 /*  1010 */    76,   77,   90,   89,   88,   98,  101,   96,   95,   94,
 /*  1020 */    92,   91,   93,   13,  164,  259,  260,  232,  668,   60,
 /*  1030 */   263,   72,   69,   68,   67,   71,   70,   66,   65,   63,
 /*  1040 */    62,   61,   64,   59,   10,   73,   74,   80,   79,   78,
 /*  1050 */    86,   85,   84,   83,   82,   81,   87,   75,   76,   77,
 /*  1060 */    90,   89,   88,   98,  101,   96,   95,   94,   92,   91,
 /*  1070 */    93,  190,  361,  264,  137,  658,  775,   60,   39,   72,
 /*  1080 */    69,   68,   67,   71,   70,   66,   65,   63,   62,   61,
 /*  1090 */    64,   59,   58,   73,   74,   80,   79,   78,   86,   85,
 /*  1100 */    84,   83,   82,   81,   87,   75,   76,   77,   90,   89,
 /*  1110 */    88,   98,  101,   96,   95,   94,   92,   91,   93,  235,
 /*  1120 */   698,  695,  696,   24,  290,   60,  140,  141,  763,   18,
 /*  1130 */   871,  872,  359,   21,   57,  867,  697,  762,  990,  764,
 /*  1140 */   761,  231,  190,  863,  760,  869,  144,   72,   69,   68,
 /*  1150 */    67,   71,   70,   66,   65,   63,   62,   61,   64,   59,
 /*  1160 */    46,   73,   74,   80,   79,   78,   86,   85,   84,   83,
 /*  1170 */    82,   81,   87,   75,   76,   77,   90,   89,   88,   98,
 /*  1180 */   101,   96,   95,   94,   92,   91,   93,  125,  285,  146,
 /*  1190 */    17,  286,  699,   60,  288,   72,   69,   68,   67,   71,
 /*  1200 */    70,   66,   65,   63,   62,   61,   64,   59,  864,   73,
 /*  1210 */    74,   80,   79,   78,   86,   85,   84,   83,   82,   81,
 /*  1220 */    87,   75,   76,   77,   90,   89,   88,   98,  101,   96,
 /*  1230 */    95,   94,   92,   91,   93,  289,  829,  291,  292,  828,
 /*  1240 */   827,   60,  147,  707,  296,   72,   69,   68,   67,   71,
 /*  1250 */    70,   66,   65,   63,   62,   61,   64,   59,  733,   73,
 /*  1260 */    74,   80,   79,   78,   86,   85,   84,   83,   82,   81,
 /*  1270 */    87,   75,   76,   77,   90,   89,   88,   98,  101,   96,
 /*  1280 */    95,   94,   92,   91,   93,  190,  361,  819,   48,  300,
 /*  1290 */    59,   60,   73,   74,   80,   79,   78,   86,   85,   84,
 /*  1300 */    83,   82,   81,   87,   75,   76,   77,   90,   89,   88,
 /*  1310 */    98,  101,   96,   95,   94,   92,   91,   93,  157,  121,
 /*  1320 */    32,  978,   33,  151,   60,   49,  970,  156,  799,   51,
 /*  1330 */    52,    7,   23,  245,   11,   35,  299,   53,  796,   87,
 /*  1340 */    75,   76,   77,   90,   89,   88,   98,  101,   96,   95,
 /*  1350 */    94,   92,   91,   93,   54,  231,  190,  863,   36,  946,
 /*  1360 */    60,  321,  322,  945,  782,  783,  784,  785,  786,  787,
 /*  1370 */   788,  789,  790,  791,  792,  793,  794,  795,  797,  348,
 /*  1380 */   341,  287,  342,  338,  798,  944,  336,  192,  361,  943,
 /*  1390 */   323,   37,  272,  326,  327,  674,  381,  379,  372,  361,
 /*  1400 */   366,  328,  364,  352,  145,  858,  859,  860,  809,  798,
 /*  1410 */   810,  248,  816,  940,  939,  938,  240,  240,  152,   25,
 /*  1420 */   814, 1166,   74,   80,   79,   78,   86,   85,   84,   83,
 /*  1430 */    82,   81,   87,   75,   76,   77,   90,   89,   88,   98,
 /*  1440 */   101,   96,   95,   94,   92,   91,   93,  143,  805,  187,
 /*  1450 */   361,   26,   27,   60,  804,  194,  361,  231,  192,  863,
 /*  1460 */   701,  703,  251,   28,  191,  361,  802,  344,  231,  879,
 /*  1470 */   863,  704,  705,   42,  801,  800,   56,  160,  942,  115,
 /*  1480 */   161,   20,  673,  355,  353,  354,  287,  356,   97,  798,
 /*  1490 */  1000,  706,  284,   40,   40,   60,  927,  272,  252,  701,
 /*  1500 */   703,  381,  379,  372,  278,  366,    3,  364,  352,  145,
 /*  1510 */   704,  705,  870,  809,  798,  810,  122,  191,  361,  231,
 /*  1520 */   187,  863,  185,  361,  102,  231,  194,  863,  252,  252,
 /*  1530 */   706,  365,   40,   40,  231,  191,  863,   15,  363,  937,
 /*  1540 */   952,  936,  332,  952,  952,  952,  331,  330,  316,  162,
 /*  1550 */   170,  311,   80,   79,   78,   86,   85,   84,   83,   82,
 /*  1560 */    81,   87,   75,   76,   77,   90,   89,   88,   98,  101,
 /*  1570 */    96,   95,   94,   92,   91,   93,   15,  689,   42,  249,
 /*  1580 */   271,  367,   60,  368,  369,  370,  371,  231,  191,  863,
 /*  1590 */   111,  110,  231,  185,  863,  963,  191,  361, 1100,  108,
 /*  1600 */   109,  232,   31,  244,  373,   29,  781,  124,  374, 1099,
 /*  1610 */   942,  861,  688,  111,  110,  361,  138,  139,  926,  378,
 /*  1620 */   380,  798,  108,  109,  142,   31,  687,  928, 1014,  947,
 /*  1630 */  1014, 1014,  774,  361,  861,    1,  361,  669,    4,  862,
 /*  1640 */  1014,  926,  773,  776,  777,  809,  798,  810,  122,  769,
 /*  1650 */   928, 1014, 1014,  752,  753,  754,  755,  756,  282,  281,
 /*  1660 */   190,  361,  862, 1014, 1014, 1014,  231,  191,  863, 1014,
 /*  1670 */   317,  937,  952,  936,  332,  952,  952,  952,  331,  330,
 /*  1680 */   316, 1014, 1014,  311,  231,  878,  863,  191,  361, 1014,
 /*  1690 */  1014,  107,  106,  105,  104,  929,  930,  931,  932,  933,
 /*  1700 */   934,  942,  231,  877,  863,  231,  876,  863,  242, 1014,
 /*  1710 */  1014,  317,  798, 1014,  107,  106,  105,  104,  929,  930,
 /*  1720 */   931,  932,  933,  934, 1014, 1014, 1014,  279,  191,  361,
 /*  1730 */   231,  190,  863,  287, 1014, 1014,  809,  798,  810,  122,
 /*  1740 */  1014, 1014,  942, 1014,  272, 1014, 1014,  717, 1014,  379,
 /*  1750 */   372, 1014,  366,  798,  364,  352,  145,  231,  191,  863,
 /*  1760 */  1014, 1014,  937,  953,  936,  332,  953,  953,  953,  331,
 /*  1770 */   330,  316,  361, 1014,  311, 1014, 1014,  809,  798,  810,
 /*  1780 */   122, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,
 /*  1790 */  1014, 1014, 1014, 1014, 1014,  191,  361, 1014,  231,  191,
 /*  1800 */   863, 1014,  317,  937,  953,  936,  332,  953,  953,  953,
 /*  1810 */   331,  330,  316,  190,  361,  311, 1014, 1014, 1014,  191,
 /*  1820 */   361, 1014, 1014, 1014, 1014,   42, 1014, 1014,  720, 1014,
 /*  1830 */  1014, 1014, 1014,  942, 1014, 1014, 1014,  722,  721,  725,
 /*  1840 */  1014,  231,  875,  863,  798,  317, 1014, 1014, 1014,  194,
 /*  1850 */   361, 1014, 1014, 1014,  726,  727,  723,  724,  728,  361,
 /*  1860 */  1014,  243,  191,  361, 1014,  231,  191,  863,  809,  798,
 /*  1870 */   810,  122,  719,  964, 1014, 1014,  942, 1014, 1014, 1014,
 /*  1880 */  1014, 1014, 1014,  231,  190,  863,  361,  798, 1014,  231,
 /*  1890 */   191,  863,  253, 1014,  937,  968,  936,  332,  968,  968,
 /*  1900 */   968,  331,  330,  316,   15, 1014,  311, 1014, 1014, 1014,
 /*  1910 */  1014,  809,  798,  810,  122, 1014,  190,  361, 1014,  231,
 /*  1920 */   194,  863,  253,  253, 1014, 1014,  190,  361,  231,  874,
 /*  1930 */   863, 1014,  231,  191,  863,  317, 1014,  937,  967,  936,
 /*  1940 */   332,  967,  967,  967,  331,  330,  316,  138,  139,  311,
 /*  1950 */  1014, 1014,  191,  361, 1014,  231,  873,  863, 1014, 1014,
 /*  1960 */  1014, 1014, 1014,  774,  246, 1014,  942, 1014,  669, 1014,
 /*  1970 */  1014, 1014, 1014, 1014,  247, 1014,  317,  798,  174,  361,
 /*  1980 */   770, 1014,  175,  361, 1014, 1014,  231,  190,  863,  126,
 /*  1990 */   361, 1014, 1014,  191,  361, 1014,  231,  190,  863, 1014,
 /*  2000 */  1014,  809,  798,  810,  122, 1014, 1014,  942, 1014, 1014,
 /*  2010 */  1014,  186,  361, 1014, 1014, 1014, 1014, 1014,  798, 1014,
 /*  2020 */   317, 1014,  231,  191,  863, 1014, 1014,  937,  966,  936,
 /*  2030 */   332,  966,  966,  966,  331,  330,  316,  191,  361,  311,
 /*  2040 */  1014, 1014,  809,  798,  810,  122, 1014, 1014,  231,  174,
 /*  2050 */   863,  942,  231,  175,  863, 1014, 1014, 1014, 1014,  231,
 /*  2060 */   126,  863,  798,  231,  191,  863,  188,  361,  937,  957,
 /*  2070 */   936,  332,  957,  957,  957,  331,  330,  316,  176,  361,
 /*  2080 */   311,  231,  186,  863, 1014, 1014,  809,  798,  810,  122,
 /*  2090 */   177,  361, 1014,  178,  361, 1014, 1014, 1014, 1014, 1014,
 /*  2100 */   179,  361, 1014, 1014, 1014, 1014, 1014,  231,  191,  863,
 /*  2110 */   317, 1014,  937,  133,  936,  332,  133,  133,  133,  331,
 /*  2120 */   330,  316, 1014, 1014,  311, 1014, 1014,  191,  361, 1014,
 /*  2130 */  1014, 1014, 1014, 1014, 1014, 1014,  231,  188,  863, 1014,
 /*  2140 */  1014,  942, 1014, 1014, 1014, 1014,  111,  110,  231,  176,
 /*  2150 */   863, 1014,  798, 1014, 1014,  108,  109, 1014,   31, 1014,
 /*  2160 */   231,  177,  863,  231,  178,  863,  357,  861, 1014, 1014,
 /*  2170 */   231,  179,  863, 1014,  926, 1014,  809,  798,  810,  122,
 /*  2180 */  1014, 1014, 1014,  928, 1014, 1014, 1014, 1014, 1014, 1014,
 /*  2190 */  1014, 1014, 1014, 1014, 1014,  862, 1014,  231,  191,  863,
 /*  2200 */  1014, 1014,  937,  955,  936,  332,  955,  955,  955,  331,
 /*  2210 */   330,  316, 1014, 1014,  311, 1014, 1014, 1014,   86,   85,
 /*  2220 */    84,   83,   82,   81,   87,   75,   76,   77,   90,   89,
 /*  2230 */    88,   98,  101,   96,   95,   94,   92,   91,   93, 1014,
 /*  2240 */  1014, 1014, 1014, 1014, 1014,   60, 1014,  107,  106,  105,
 /*  2250 */   104,  929,  930,  931,  932,  933,  934,  111,  110, 1014,
 /*  2260 */  1014, 1014, 1014,  191,  361, 1014,  108,  109, 1014,   31,
 /*  2270 */   111,  110, 1014, 1014, 1014, 1014, 1014, 1014,  861,  108,
 /*  2280 */   109, 1014,   31,  111,  110,  926, 1014, 1014,  798,   22,
 /*  2290 */  1014,  362,  108,  109,  928,   31, 1014, 1014,  926, 1014,
 /*  2300 */  1014, 1014, 1014, 1014,  861, 1014,  862,  928, 1014, 1014,
 /*  2310 */  1014,  926,  809,  798,  810,  122, 1014, 1014, 1014,  862,
 /*  2320 */   928, 1014, 1014, 1014,  180,  361, 1014, 1014, 1014,  189,
 /*  2330 */   361, 1014,  862,  231,  191,  863,  193,  361, 1014,  181,
 /*  2340 */   361,  963, 1014, 1014,  208,  361,  960, 1014,  313,  303,
 /*  2350 */   182,  361, 1014,  919,  361, 1014, 1014, 1014,  107,  106,
 /*  2360 */   105,  104,  929,  930,  931,  932,  933,  934, 1014,  195,
 /*  2370 */   361,  107,  106,  105,  104,  929,  930,  931,  932,  933,
 /*  2380 */   934,  196,  361, 1014,  107,  106,  105,  104,  929,  930,
 /*  2390 */   931,  932,  933,  934,  231,  180,  863, 1014, 1014,  231,
 /*  2400 */   189,  863,  197,  361, 1014, 1014,  231,  193,  863,  231,
 /*  2410 */   181,  863,  198,  361,  231,  208,  863, 1014, 1014, 1014,
 /*  2420 */   231,  182,  863,  231,  919,  863,  199,  361, 1014,  200,
 /*  2430 */   361, 1014,  201,  361, 1014, 1014, 1014,  202,  361,  231,
 /*  2440 */   195,  863, 1014,  203,  361, 1014, 1014, 1014, 1014, 1014,
 /*  2450 */  1014,  231,  196,  863,  204,  361, 1014,  205,  361, 1014,
 /*  2460 */  1014, 1014,  206,  361, 1014,  209,  361, 1014,  210,  361,
 /*  2470 */  1014, 1014,  231,  197,  863, 1014, 1014, 1014,  221,  361,
 /*  2480 */  1014, 1014,  231,  198,  863,  222,  361, 1014,  223,  361,
 /*  2490 */  1014, 1014, 1014,  211,  361, 1014,  231,  199,  863,  231,
 /*  2500 */   200,  863,  231,  201,  863, 1014, 1014,  231,  202,  863,
 /*  2510 */   212,  361, 1014,  231,  203,  863, 1014, 1014,  213,  361,
 /*  2520 */  1014, 1014,  214,  361,  231,  204,  863,  231,  205,  863,
 /*  2530 */  1014, 1014,  231,  206,  863,  231,  209,  863,  231,  210,
 /*  2540 */   863,  215,  361, 1014,  216,  361, 1014, 1014,  231,  221,
 /*  2550 */   863,  217,  361, 1014, 1014,  231,  222,  863,  231,  223,
 /*  2560 */   863,  218,  361,  231,  211,  863,  219,  361, 1014,  220,
 /*  2570 */   361, 1014, 1014,  224,  361, 1014,  225,  361, 1014, 1014,
 /*  2580 */   231,  212,  863,  226,  361, 1014,  254,  361,  231,  213,
 /*  2590 */   863, 1014,  231,  214,  863,  255,  361, 1014,  360,  361,
 /*  2600 */  1014,  256,  361, 1014,  257,  361, 1014,  258,  361, 1014,
 /*  2610 */  1014,  231,  215,  863,  231,  216,  863,  207,  361, 1014,
 /*  2620 */  1014,  231,  217,  863, 1014,  228,  361, 1014,  183,  361,
 /*  2630 */  1014,  231,  218,  863, 1014, 1014,  231,  219,  863,  231,
 /*  2640 */   220,  863, 1014,  231,  224,  863,  231,  225,  863, 1014,
 /*  2650 */  1014, 1014, 1014,  231,  226,  863,  231,  254,  863,  172,
 /*  2660 */   361, 1014,  227,  361, 1014,  231,  255,  863,  231,  360,
 /*  2670 */   863,  231,  256,  863,  231,  257,  863,  231,  258,  863,
 /*  2680 */  1014,  184,  361, 1014, 1014, 1014, 1014,  231,  207,  863,
 /*  2690 */  1014, 1014, 1014, 1014, 1014,  231,  228,  863,  231,  183,
 /*  2700 */   863, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,
 /*  2710 */  1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,
 /*  2720 */  1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,  231,
 /*  2730 */   172,  863,  231,  227,  863, 1014, 1014, 1014, 1014, 1014,
 /*  2740 */  1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,
 /*  2750 */  1014,  231,  184,  863,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    33,   34,  163,  164,  165,  166,  167,  168,  169,   42,
 /*    10 */    43,   44,   45,   46,  175,  198,   49,  208,  209,   49,
 /*    20 */    53,   54,  203,  204,  205,  206,  198,   54,   61,   54,
 /*    30 */    63,   64,   65,   66,   44,   65,   50,   70,  199,  222,
 /*    40 */   223,  224,  225,   53,   54,  228,  230,  231,   62,   82,
 /*    50 */   222,  223,  224,  225,   64,   82,  228,   90,   91,   92,
 /*    60 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    70 */   103,  104,  105,  106,  156,  108,  109,   45,   46,   53,
 /*    80 */    90,   91,   92,   93,   94,   95,   96,   97,   98,   99,
 /*    90 */   100,  101,  102,  103,  104,  105,  106,   71,  108,  109,
 /*   100 */   156,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*   110 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   120 */   202,  154,  155,   29,   30,   31,   32,   33,   34,   35,
 /*   130 */    36,   37,   38,   39,   40,   33,   34,  156,  194,  195,
 /*   140 */   196,   47,  161,  162,   42,   43,   44,   45,   46,   46,
 /*   150 */   157,   49,  230,  231,   49,   53,   54,  173,  174,  166,
 /*   160 */   167,  168,   40,   61,   54,   63,   64,   65,   66,   47,
 /*   170 */   177,   66,   70,   63,   64,  182,  183,  184,  185,  186,
 /*   180 */   187,  241,  242,   46,   82,   90,   91,   92,   93,   94,
 /*   190 */    95,   54,   90,   91,   92,   93,   94,   95,   96,   97,
 /*   200 */    98,   99,  100,  101,  102,  103,  104,  105,  106,   54,
 /*   210 */   108,  109,   27,   28,   29,   30,   31,   32,   33,   34,
 /*   220 */    35,   36,   37,   38,   39,   40,  233,  243,  244,  245,
 /*   230 */   246,  247,   47,  172,  173,  174,  134,  135,  136,  137,
 /*   240 */   138,  139,  140,  141,  142,  143,  144,  145,  146,  147,
 /*   250 */   148,  149,  150,  151,  152,   62,  154,  155,   33,   34,
 /*   260 */    35,   36,   37,   38,   39,   40,  261,  262,  130,  198,
 /*   270 */    33,   34,   47,   35,   36,   37,   38,   39,   40,   42,
 /*   280 */    43,   44,   45,   46,  198,   47,   49,  230,  231,  211,
 /*   290 */    53,   54,  207,  222,  223,  224,  225,   54,   61,  228,
 /*   300 */    63,   64,   65,  110,  243,  244,  245,   70,  222,  223,
 /*   310 */   224,  225,  226,  227,  228,   66,  159,  160,   66,   82,
 /*   320 */     1,   21,   73,   74,  238,   73,   74,   90,   91,   92,
 /*   330 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*   340 */   103,  104,  105,  106,   44,  108,  109,  198,   28,   29,
 /*   350 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   360 */    40,    0,  234,  150,  151,   46,   54,   47,  240,  241,
 /*   370 */   242,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*   380 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   390 */    44,  154,  155,  144,  207,  198,  144,  191,  192,   53,
 /*   400 */    54,   55,   56,   57,   58,  248,   60,   34,    1,   48,
 /*   410 */    64,  207,   51,   52,   53,   49,  257,   44,   72,  222,
 /*   420 */   223,  224,  225,   49,   50,  228,  181,   14,   67,   49,
 /*   430 */    50,   65,   71,  198,   73,   74,   90,   91,   92,   93,
 /*   440 */    94,   95,   96,   97,   98,   99,  100,  101,  102,  103,
 /*   450 */   104,  105,  106,   46,  108,  109,  110,  222,  223,  224,
 /*   460 */   225,  231,  116,  117,  118,  119,  120,  121,  122,  123,
 /*   470 */   124,  125,  126,  127,  128,  129,    1,    2,    3,    4,
 /*   480 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   76,
 /*   490 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*   500 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*   510 */    35,   36,   37,   38,   39,   40,   66,   49,  156,   50,
 /*   520 */    50,   50,   47,   49,   50,   50,   76,   77,   78,   79,
 /*   530 */    80,   81,   62,   62,   66,  173,  174,   62,  178,    1,
 /*   540 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   550 */    12,   13,   54,   15,   16,   17,   18,   19,   20,   21,
 /*   560 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   570 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  156,
 /*   580 */    54,   33,   34,  221,  115,   47,   50,   50,   50,  174,
 /*   590 */    42,   43,   44,   45,   50,   50,  173,  174,   62,  181,
 /*   600 */    62,   53,   54,   66,  157,  243,  244,  245,  156,   61,
 /*   610 */    66,   66,   64,  181,  167,  168,   50,   14,   70,   30,
 /*   620 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*   630 */    82,  105,   66,  181,  187,  179,   47,  190,   90,   91,
 /*   640 */    92,   93,   94,   95,   96,   97,   98,   99,  100,  101,
 /*   650 */   102,  103,  104,  105,  106,   45,  108,  109,  243,  244,
 /*   660 */   245,   50,  173,  174,  181,  181,  243,  244,  245,  217,
 /*   670 */   218,  219,  220,   62,   55,   56,   57,   58,   59,   60,
 /*   680 */   233,  181,  134,  135,  136,  137,  138,  139,  140,  141,
 /*   690 */   142,  143,    1,    2,    3,    4,    5,    6,    7,    8,
 /*   700 */     9,   10,   11,   12,   13,  216,   15,   16,   17,   18,
 /*   710 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   720 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   730 */    39,   40,  243,  244,  245,  246,  247,  181,   47,  210,
 /*   740 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*   750 */    11,   12,   13,   62,   15,   16,   17,   18,   19,   20,
 /*   760 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   770 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*   780 */    49,  213,   61,  214,  212,   45,   47,   49,  170,   50,
 /*   790 */   239,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   800 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*   810 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   820 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   830 */    40,   50,   54,  192,  212,  237,   54,   47,  262,    1,
 /*   840 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   850 */    12,   13,   73,   15,   16,   17,   18,   19,   20,   21,
 /*   860 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   870 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  235,
 /*   880 */   181,   20,  229,  181,  196,   47,   50,    1,    2,    3,
 /*   890 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   900 */    62,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   910 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*   920 */    34,   35,   36,   37,   38,   39,   40,  171,  170,   14,
 /*   930 */   197,  170,   61,   47,  174,    1,    2,    3,    4,    5,
 /*   940 */     6,    7,    8,    9,   10,   11,   12,   13,   62,   15,
 /*   950 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   960 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*   970 */    36,   37,   38,   39,   40,  200,  180,  176,  213,  213,
 /*   980 */   213,   47,  193,    1,    2,    3,    4,    5,    6,    7,
 /*   990 */     8,    9,   10,   11,   12,   13,   62,   15,   16,   17,
 /*  1000 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*  1010 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  1020 */    38,   39,   40,  176,   65,   54,   53,   44,   62,   47,
 /*  1030 */    61,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1040 */    10,   11,   12,   13,   62,   15,   16,   17,   18,   19,
 /*  1050 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1060 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1070 */    40,  173,  174,   45,   54,   54,   49,   47,   65,    1,
 /*  1080 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1090 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  1100 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  1110 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  221,
 /*  1120 */    56,   57,   58,   50,   60,   47,   47,   47,   66,   65,
 /*  1130 */    42,   43,   44,   45,   46,   62,   72,   66,   49,   49,
 /*  1140 */    66,  243,  244,  245,   61,  115,   45,    1,    2,    3,
 /*  1150 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  1160 */    45,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1170 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  1180 */    34,   35,   36,   37,   38,   39,   40,   65,   54,   66,
 /*  1190 */    65,   71,   62,   47,   61,    1,    2,    3,    4,    5,
 /*  1200 */     6,    7,    8,    9,   10,   11,   12,   13,   62,   15,
 /*  1210 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*  1220 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1230 */    36,   37,   38,   39,   40,   45,   62,   61,   45,   62,
 /*  1240 */    61,   47,   61,   49,   45,    1,    2,    3,    4,    5,
 /*  1250 */     6,    7,    8,    9,   10,   11,   12,   13,   54,   15,
 /*  1260 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*  1270 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1280 */    36,   37,   38,   39,   40,  173,  174,   49,    1,   54,
 /*  1290 */    13,   47,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1300 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1310 */    33,   34,   35,   36,   37,   38,   39,   40,   44,   50,
 /*  1320 */    50,   66,   65,   50,   47,    1,   14,   53,   54,   45,
 /*  1330 */    45,  153,   49,  221,   45,   49,  156,   45,   64,   26,
 /*  1340 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1350 */    37,   38,   39,   40,   45,  243,  244,  245,   65,   49,
 /*  1360 */    47,    1,   54,   49,   90,   91,   92,   93,   94,   95,
 /*  1370 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*  1380 */   106,   52,  108,  109,  198,   49,  172,  173,  174,   49,
 /*  1390 */   115,   65,   63,    1,  115,   66,   67,   68,   69,  174,
 /*  1400 */    71,   46,   73,   74,   75,  131,  132,  133,  222,  223,
 /*  1410 */   224,  225,  232,   49,   49,   49,  236,  237,   62,   50,
 /*  1420 */   115,   54,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1430 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  1440 */    34,   35,   36,   37,   38,   39,   40,  156,   21,  173,
 /*  1450 */   174,   20,   50,   47,   21,  173,  174,  243,  244,  245,
 /*  1460 */   156,  157,   20,   20,  173,  174,   21,   54,  243,  244,
 /*  1470 */   245,  167,  168,  144,   21,   54,    1,   66,  187,   65,
 /*  1480 */    54,   45,   48,   54,   62,   21,   52,   20,   14,  198,
 /*  1490 */    62,  187,  188,  189,  190,   47,   61,   63,  216,  156,
 /*  1500 */   157,   67,   68,   69,  213,   71,  215,   73,   74,   75,
 /*  1510 */   167,  168,   54,  222,  223,  224,  225,  173,  174,  243,
 /*  1520 */   244,  245,  173,  174,    1,  243,  244,  245,  246,  247,
 /*  1530 */   187,  188,  189,  190,  243,  244,  245,  233,   54,  248,
 /*  1540 */   249,  250,  251,  252,  253,  254,  255,  256,  257,   66,
 /*  1550 */    54,  260,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1560 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1570 */    35,   36,   37,   38,   39,   40,  233,   49,  144,  156,
 /*  1580 */   156,   70,   47,   50,   54,   14,   54,  243,  244,  245,
 /*  1590 */    33,   34,  243,  244,  245,  251,  173,  174,   50,   42,
 /*  1600 */    43,   44,   45,  259,   54,  181,   49,   14,   50,   50,
 /*  1610 */   187,   54,   49,   33,   34,  174,   33,   34,   61,   54,
 /*  1620 */    54,  198,   42,   43,   54,   45,   49,   70,  263,   49,
 /*  1630 */   263,  263,   49,  174,   54,   65,  174,   54,  215,   82,
 /*  1640 */   263,   61,  218,  219,  220,  222,  223,  224,  225,   66,
 /*  1650 */    70,  263,  263,   83,   84,   85,   86,   87,   88,   89,
 /*  1660 */   173,  174,   82,  263,  263,  263,  243,  244,  245,  263,
 /*  1670 */   156,  248,  249,  250,  251,  252,  253,  254,  255,  256,
 /*  1680 */   257,  263,  263,  260,  243,  244,  245,  173,  174,  263,
 /*  1690 */   263,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*  1700 */   143,  187,  243,  244,  245,  243,  244,  245,  221,  263,
 /*  1710 */   263,  156,  198,  263,  134,  135,  136,  137,  138,  139,
 /*  1720 */   140,  141,  142,  143,  263,  263,  263,  213,  173,  174,
 /*  1730 */   243,  244,  245,   52,  263,  263,  222,  223,  224,  225,
 /*  1740 */   263,  263,  187,  263,   63,  263,  263,   66,  263,   68,
 /*  1750 */    69,  263,   71,  198,   73,   74,   75,  243,  244,  245,
 /*  1760 */   263,  263,  248,  249,  250,  251,  252,  253,  254,  255,
 /*  1770 */   256,  257,  174,  263,  260,  263,  263,  222,  223,  224,
 /*  1780 */   225,  263,  263,  263,  263,  263,  263,  263,  263,  263,
 /*  1790 */   263,  263,  263,  263,  263,  173,  174,  263,  243,  244,
 /*  1800 */   245,  263,  156,  248,  249,  250,  251,  252,  253,  254,
 /*  1810 */   255,  256,  257,  173,  174,  260,  263,  263,  263,  173,
 /*  1820 */   174,  263,  263,  263,  263,  144,  263,  263,  157,  263,
 /*  1830 */   263,  263,  263,  187,  263,  263,  263,  166,  167,  168,
 /*  1840 */   263,  243,  244,  245,  198,  156,  263,  263,  263,  173,
 /*  1850 */   174,  263,  263,  263,  183,  184,  185,  186,  187,  174,
 /*  1860 */   263,  221,  173,  174,  263,  243,  244,  245,  222,  223,
 /*  1870 */   224,  225,  201,  251,  263,  263,  187,  263,  263,  263,
 /*  1880 */   263,  263,  263,  243,  244,  245,  174,  198,  263,  243,
 /*  1890 */   244,  245,  216,  263,  248,  249,  250,  251,  252,  253,
 /*  1900 */   254,  255,  256,  257,  233,  263,  260,  263,  263,  263,
 /*  1910 */   263,  222,  223,  224,  225,  263,  173,  174,  263,  243,
 /*  1920 */   244,  245,  246,  247,  263,  263,  173,  174,  243,  244,
 /*  1930 */   245,  263,  243,  244,  245,  156,  263,  248,  249,  250,
 /*  1940 */   251,  252,  253,  254,  255,  256,  257,   33,   34,  260,
 /*  1950 */   263,  263,  173,  174,  263,  243,  244,  245,  263,  263,
 /*  1960 */   263,  263,  263,   49,  221,  263,  187,  263,   54,  263,
 /*  1970 */   263,  263,  263,  263,  221,  263,  156,  198,  173,  174,
 /*  1980 */    66,  263,  173,  174,  263,  263,  243,  244,  245,  173,
 /*  1990 */   174,  263,  263,  173,  174,  263,  243,  244,  245,  263,
 /*  2000 */   263,  222,  223,  224,  225,  263,  263,  187,  263,  263,
 /*  2010 */   263,  173,  174,  263,  263,  263,  263,  263,  198,  263,
 /*  2020 */   156,  263,  243,  244,  245,  263,  263,  248,  249,  250,
 /*  2030 */   251,  252,  253,  254,  255,  256,  257,  173,  174,  260,
 /*  2040 */   263,  263,  222,  223,  224,  225,  263,  263,  243,  244,
 /*  2050 */   245,  187,  243,  244,  245,  263,  263,  263,  263,  243,
 /*  2060 */   244,  245,  198,  243,  244,  245,  173,  174,  248,  249,
 /*  2070 */   250,  251,  252,  253,  254,  255,  256,  257,  173,  174,
 /*  2080 */   260,  243,  244,  245,  263,  263,  222,  223,  224,  225,
 /*  2090 */   173,  174,  263,  173,  174,  263,  263,  263,  263,  263,
 /*  2100 */   173,  174,  263,  263,  263,  263,  263,  243,  244,  245,
 /*  2110 */   156,  263,  248,  249,  250,  251,  252,  253,  254,  255,
 /*  2120 */   256,  257,  263,  263,  260,  263,  263,  173,  174,  263,
 /*  2130 */   263,  263,  263,  263,  263,  263,  243,  244,  245,  263,
 /*  2140 */   263,  187,  263,  263,  263,  263,   33,   34,  243,  244,
 /*  2150 */   245,  263,  198,  263,  263,   42,   43,  263,   45,  263,
 /*  2160 */   243,  244,  245,  243,  244,  245,   53,   54,  263,  263,
 /*  2170 */   243,  244,  245,  263,   61,  263,  222,  223,  224,  225,
 /*  2180 */   263,  263,  263,   70,  263,  263,  263,  263,  263,  263,
 /*  2190 */   263,  263,  263,  263,  263,   82,  263,  243,  244,  245,
 /*  2200 */   263,  263,  248,  249,  250,  251,  252,  253,  254,  255,
 /*  2210 */   256,  257,  263,  263,  260,  263,  263,  263,   20,   21,
 /*  2220 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  2230 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  263,
 /*  2240 */   263,  263,  263,  263,  263,   47,  263,  134,  135,  136,
 /*  2250 */   137,  138,  139,  140,  141,  142,  143,   33,   34,  263,
 /*  2260 */   263,  263,  263,  173,  174,  263,   42,   43,  263,   45,
 /*  2270 */    33,   34,  263,  263,  263,  263,  263,  263,   54,   42,
 /*  2280 */    43,  263,   45,   33,   34,   61,  263,  263,  198,   65,
 /*  2290 */   263,   54,   42,   43,   70,   45,  263,  263,   61,  263,
 /*  2300 */   263,  263,  263,  263,   54,  263,   82,   70,  263,  263,
 /*  2310 */   263,   61,  222,  223,  224,  225,  263,  263,  263,   82,
 /*  2320 */    70,  263,  263,  263,  173,  174,  263,  263,  263,  173,
 /*  2330 */   174,  263,   82,  243,  244,  245,  173,  174,  263,  173,
 /*  2340 */   174,  251,  263,  263,  173,  174,  256,  263,  258,  259,
 /*  2350 */   173,  174,  263,  173,  174,  263,  263,  263,  134,  135,
 /*  2360 */   136,  137,  138,  139,  140,  141,  142,  143,  263,  173,
 /*  2370 */   174,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*  2380 */   143,  173,  174,  263,  134,  135,  136,  137,  138,  139,
 /*  2390 */   140,  141,  142,  143,  243,  244,  245,  263,  263,  243,
 /*  2400 */   244,  245,  173,  174,  263,  263,  243,  244,  245,  243,
 /*  2410 */   244,  245,  173,  174,  243,  244,  245,  263,  263,  263,
 /*  2420 */   243,  244,  245,  243,  244,  245,  173,  174,  263,  173,
 /*  2430 */   174,  263,  173,  174,  263,  263,  263,  173,  174,  243,
 /*  2440 */   244,  245,  263,  173,  174,  263,  263,  263,  263,  263,
 /*  2450 */   263,  243,  244,  245,  173,  174,  263,  173,  174,  263,
 /*  2460 */   263,  263,  173,  174,  263,  173,  174,  263,  173,  174,
 /*  2470 */   263,  263,  243,  244,  245,  263,  263,  263,  173,  174,
 /*  2480 */   263,  263,  243,  244,  245,  173,  174,  263,  173,  174,
 /*  2490 */   263,  263,  263,  173,  174,  263,  243,  244,  245,  243,
 /*  2500 */   244,  245,  243,  244,  245,  263,  263,  243,  244,  245,
 /*  2510 */   173,  174,  263,  243,  244,  245,  263,  263,  173,  174,
 /*  2520 */   263,  263,  173,  174,  243,  244,  245,  243,  244,  245,
 /*  2530 */   263,  263,  243,  244,  245,  243,  244,  245,  243,  244,
 /*  2540 */   245,  173,  174,  263,  173,  174,  263,  263,  243,  244,
 /*  2550 */   245,  173,  174,  263,  263,  243,  244,  245,  243,  244,
 /*  2560 */   245,  173,  174,  243,  244,  245,  173,  174,  263,  173,
 /*  2570 */   174,  263,  263,  173,  174,  263,  173,  174,  263,  263,
 /*  2580 */   243,  244,  245,  173,  174,  263,  173,  174,  243,  244,
 /*  2590 */   245,  263,  243,  244,  245,  173,  174,  263,  173,  174,
 /*  2600 */   263,  173,  174,  263,  173,  174,  263,  173,  174,  263,
 /*  2610 */   263,  243,  244,  245,  243,  244,  245,  173,  174,  263,
 /*  2620 */   263,  243,  244,  245,  263,  173,  174,  263,  173,  174,
 /*  2630 */   263,  243,  244,  245,  263,  263,  243,  244,  245,  243,
 /*  2640 */   244,  245,  263,  243,  244,  245,  243,  244,  245,  263,
 /*  2650 */   263,  263,  263,  243,  244,  245,  243,  244,  245,  173,
 /*  2660 */   174,  263,  173,  174,  263,  243,  244,  245,  243,  244,
 /*  2670 */   245,  243,  244,  245,  243,  244,  245,  243,  244,  245,
 /*  2680 */   263,  173,  174,  263,  263,  263,  263,  243,  244,  245,
 /*  2690 */   263,  263,  263,  263,  263,  243,  244,  245,  243,  244,
 /*  2700 */   245,  263,  263,  263,  263,  263,  263,  263,  263,  263,
 /*  2710 */   263,  263,  263,  263,  263,  263,  263,  263,  263,  263,
 /*  2720 */   263,  263,  263,  263,  263,  263,  263,  263,  263,  243,
 /*  2730 */   244,  245,  243,  244,  245,  263,  263,  263,  263,  263,
 /*  2740 */   263,  263,  263,  263,  263,  263,  263,  263,  263,  263,
 /*  2750 */   263,  243,  244,  245,
};
#define YY_SHIFT_USE_DFLT (2754)
#define YY_SHIFT_COUNT    (382)
#define YY_SHIFT_MIN      (-33)
#define YY_SHIFT_MAX      (2250)
static const short yy_shift_ofst[] = {
 /*     0 */  2754,  237,  -33,  237,  102,  237,  237,  237,  237,  237,
 /*    10 */   237,  548, 1329, 1434, 1681,  346,  361,  249,  249, 2237,
 /*    20 */  2237, 2237, 2250, 2250, 2237,  -10,  -10,  -10,  -10, 1557,
 /*    30 */  1580, 2113, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 1583,
 /*    40 */   252, 1274,  -10, 2224, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    50 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    60 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    70 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    80 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    90 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*   100 */  2250, 2250, 2250, 1914, 2250, 2250, 2250, 2250, 2250, 2250,
 /*   110 */  2250, 2250,  450,  193,  -25,  155,  -30, 1570,  319,   32,
 /*   120 */   103,  138,  243,  103,  312, 2754, 1244,   95,  373,  373,
 /*   130 */   373,  -27,  407,  213,  366,  498,  498,  603,  498,  498,
 /*   140 */   498,  498,  610,  731,  721,  740,  738,  781,  778,  740,
 /*   150 */   782,  243,  779,  103,  103,  498,  861,  498,  155,  836,
 /*   160 */   738,  915,  738,  871, 2754, 2754, 2754, 2754, 2754, 2754,
 /*   170 */  2754, 2754,  475,  538,  691,  739,  790,  838,  886,  934,
 /*   180 */   982, 1030, 1078, 1146, 1194, 1244, 1244, 1244, 1244, 1244,
 /*   190 */  1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244,
 /*   200 */  1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244, 1277, 1406,
 /*   210 */  1535, 2198, 2198, 2198, 1313, 1313, 1313, 1313, 1313, 1313,
 /*   220 */   185,  320,   94,  589,  225,  225,  225,  238,  238,  619,
 /*   230 */  1064, 1088,  110,   26,  105,  374,  -14,  470,  413,  471,
 /*   240 */   380,  537,  544,  469,  536,  474,  545,  566,  137,  468,
 /*   250 */   300,  526,  611, 1073,  122,  122,  122,  122,  122,  959,
 /*   260 */   971,  973,  983,  966,  969, 1028,  983, 1020, 1021,  983,
 /*   270 */   983, 1027, 1013, 1079, 1080, 1089, 1090, 1062, 1071, 1074,
 /*   280 */  1083, 1101, 1115, 1122, 1123, 1125, 1134, 1120, 1130, 1133,
 /*   290 */  1190, 1174, 1176, 1193, 1177, 1179, 1181, 1199, 1204, 1238,
 /*   300 */  1287, 1235, 1269, 1270, 1255, 1257, 1273, 1324, 1312, 1284,
 /*   310 */  1285, 1178, 1283, 1286, 1289, 1292, 1309,  731, 1310, 1314,
 /*   320 */  1336, 1293, 1360, 1308, 1275, 1340, 1326, 1392, 1279, 1355,
 /*   330 */  1364, 1365, 1366, 1367, 1356, 1369, 1305, 1427, 1431, 1433,
 /*   340 */  1402, 1442, 1443,  983, 1445, 1413, 1453, 1442, 1421, 1475,
 /*   350 */  1411, 1414, 1426, 1436, 1422, 1464, 1429, 1467, 1428, 1458,
 /*   360 */  1448, 1435, 1474, 1523, 1484, 1483, 1496, 1528, 1511, 1533,
 /*   370 */  1530, 1571, 1532, 1548, 1550, 1558, 1559, 1563, 1593, 1565,
 /*   380 */  1577, 1566, 1435,
};
#define YY_REDUCE_USE_DFLT (-192)
#define YY_REDUCE_COUNT (171)
#define YY_REDUCE_MIN   (-191)
#define YY_REDUCE_MAX   (2508)
static const short yy_reduce_ofst[] = {
 /*     0 */   -19, 1291, 1423, 1514, 1555, 1646, 1689, 1779, 1820, 1864,
 /*    10 */  1954, 2090,   -7,   -7, 1671,   86, -161, 1304, 1343,  489,
 /*    20 */  1282, 1676,  362, 1344,  -16, -183, -172,   71,  197,  898,
 /*    30 */  1112,  423, 1622, 1487, 1640,   61, 1743, 1753, 1214,  452,
 /*    40 */   447,  235, 1186, 1276, 1349, 1805, 1809, 1816, 1838, 1893,
 /*    50 */  1905, 1917, 1920, 1927, 2151, 2156, 2163, 2166, 2171, 2177,
 /*    60 */  2180, 2196, 2208, 2229, 2239, 2253, 2256, 2259, 2264, 2270,
 /*    70 */  2281, 2284, 2289, 2292, 2295, 2305, 2312, 2315, 2320, 2337,
 /*    80 */  2345, 2349, 2368, 2371, 2378, 2388, 2393, 2396, 2400, 2403,
 /*    90 */  2410, 2413, 2422, 2425, 2428, 2431, 2434, 2444, 2452, 2455,
 /*   100 */  2486, 2489, 2508, 1424,  415, 1225, 1441, 1459, 1462, 1598,
 /*   110 */  1685, 1712, -181,  128, 1180,  -56,  157, -191, -184,  -78,
 /*   120 */   -78,  -60,    5,   57,  206,  -82,   78,  149,   85,  187,
 /*   130 */   204,  245,  230,  159,  360,  418,  432,  456,  483,  484,
 /*   140 */   500,  556,  529,  568,  569,  572,  618,  551,  641,  622,
 /*   150 */   598,  576,  644,  230,  230,  699,  653,  702,  688,  756,
 /*   160 */   758,  733,  761,  760,  775,  796,  801,  765,  766,  767,
 /*   170 */   789,  847,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1013, 1101, 1379, 1101, 1379, 1379, 1379, 1379, 1379, 1379,
 /*    10 */  1379, 1329, 1190, 1190, 1190, 1379, 1379, 1190, 1190, 1290,
 /*    20 */  1290, 1290, 1379, 1329, 1290, 1379, 1379, 1379, 1379, 1379,
 /*    30 */  1379, 1379, 1379, 1379, 1379, 1022, 1379, 1379, 1022, 1379,
 /*    40 */  1190, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*    50 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*    60 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*    70 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*    80 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*    90 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   100 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   110 */  1379, 1379, 1379, 1224, 1379, 1080, 1379, 1132, 1340, 1187,
 /*   120 */  1187, 1224, 1379, 1359, 1379, 1102, 1118, 1379, 1115, 1115,
 /*   130 */  1115, 1379, 1341, 1379, 1379, 1379, 1379, 1027, 1379, 1379,
 /*   140 */  1379, 1379, 1134, 1101, 1379, 1097, 1348, 1193, 1379, 1097,
 /*   150 */  1379, 1379, 1215, 1188, 1178, 1379, 1174, 1379, 1351, 1350,
 /*   160 */  1348, 1076, 1348, 1379, 1085, 1029, 1042, 1101, 1101, 1101,
 /*   170 */  1061, 1042, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   180 */  1379, 1379, 1379, 1379, 1379, 1116, 1223, 1342, 1338, 1288,
 /*   190 */  1370, 1321, 1352, 1082, 1292, 1285, 1284, 1283, 1282, 1281,
 /*   200 */  1280, 1279, 1278, 1277, 1276, 1275, 1274, 1291, 1287, 1273,
 /*   210 */  1272, 1268, 1267, 1266, 1265, 1264, 1263, 1262, 1261, 1260,
 /*   220 */  1259, 1271, 1270, 1269, 1258, 1257, 1256, 1248, 1249, 1026,
 /*   230 */  1379, 1368, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   240 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   250 */  1379, 1379, 1379, 1379, 1255, 1254, 1252, 1251, 1250, 1379,
 /*   260 */  1379, 1379, 1028, 1379, 1379, 1379, 1034, 1379, 1379, 1146,
 /*   270 */  1145, 1379, 1379, 1379, 1036, 1379, 1379, 1379, 1379, 1379,
 /*   280 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   290 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   300 */  1222, 1379, 1365, 1328, 1379, 1379, 1339, 1379, 1379, 1379,
 /*   310 */  1379, 1332, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   320 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   330 */  1379, 1379, 1379, 1228, 1379, 1361, 1379, 1379, 1379, 1379,
 /*   340 */  1379, 1379, 1379, 1170, 1379, 1379, 1379, 1205, 1379, 1081,
 /*   350 */  1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   360 */  1253, 1373, 1228, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 /*   370 */  1379, 1379, 1379, 1058, 1379, 1379, 1057, 1379, 1379, 1379,
 /*   380 */  1379, 1379, 1023,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         EQ => nothing */
    0,  /*      MULEQ => nothing */
    0,  /*      DIVEQ => nothing */
    0,  /*      MODEQ => nothing */
    0,  /*      ADDEQ => nothing */
    0,  /*      SUBEQ => nothing */
    0,  /*      LSHEQ => nothing */
    0,  /*      RSHEQ => nothing */
    0,  /*      ANDEQ => nothing */
    0,  /*       OREQ => nothing */
    0,  /*      XOREQ => nothing */
    0,  /*     URSHEQ => nothing */
    0,  /*   QUESTION => nothing */
    0,  /*      COLON => nothing */
    0,  /*       OROR => nothing */
    0,  /*     ANDAND => nothing */
    0,  /*       EQEQ => nothing */
    0,  /*        NEQ => nothing */
    0,  /*   APPROXEQ => nothing */
    0,  /*         LT => nothing */
    0,  /*         GT => nothing */
    0,  /*       LTEQ => nothing */
    0,  /*       GTEQ => nothing */
    0,  /*     LTGTEQ => nothing */
    0,  /*         IS => nothing */
    0,  /*     DOTDOT => nothing */
    0,  /*         OR => nothing */
    0,  /*        XOR => nothing */
    0,  /*        AND => nothing */
    0,  /*        LSH => nothing */
    0,  /*        RSH => nothing */
    0,  /*       URSH => nothing */
    0,  /*        SUB => nothing */
    0,  /*        ADD => nothing */
    0,  /*        MUL => nothing */
    0,  /*        DIV => nothing */
    0,  /*        MOD => nothing */
    0,  /*  CROSSPROD => nothing */
    0,  /*    DOTPROD => nothing */
    0,  /*        POW => nothing */
    0,  /*      UNARY => nothing */
    0,  /*     ADDADD => nothing */
    0,  /*     SUBSUB => nothing */
    0,  /*        DOT => nothing */
    0,  /*     LPAREN => nothing */
    0,  /*   LBRACKET => nothing */
    0,  /*      SCOPE => nothing */
    0,  /*        EOF => nothing */
    0,  /*  SEMICOLON => nothing */
    0,  /*      COMMA => nothing */
    0,  /*    INCLUDE => nothing */
    0,  /*     EXTEND => nothing */
    0,  /*      CLASS => nothing */
    0,  /* IDENTIFIER => nothing */
    0,  /*   ABSTRACT => nothing */
    0,  /*     NATIVE => nothing */
    0,  /*         UI => nothing */
    0,  /*       PLAY => nothing */
    0,  /*   REPLACES => nothing */
    0,  /*    VERSION => nothing */
    0,  /*   STRCONST => nothing */
    0,  /*     RPAREN => nothing */
   54,  /*    DEFAULT => IDENTIFIER */
   54,  /*      COLOR => IDENTIFIER */
    0,  /*     LBRACE => nothing */
    0,  /*     RBRACE => nothing */
    0,  /*      MIXIN => nothing */
   54,  /*   PROPERTY => IDENTIFIER */
    0,  /*    FLAGDEF => nothing */
    0,  /*   INTCONST => nothing */
    0,  /*     STRUCT => nothing */
    0,  /* CLEARSCOPE => nothing */
    0,  /*      CONST => nothing */
    0,  /*       ENUM => nothing */
    0,  /*     STATES => nothing */
    0,  /*        NWS => nothing */
    0,  /*       STOP => nothing */
    0,  /*       WAIT => nothing */
    0,  /*       FAIL => nothing */
    0,  /*       LOOP => nothing */
    0,  /*       GOTO => nothing */
    0,  /*      SUPER => nothing */
    0,  /*     BRIGHT => nothing */
    0,  /*       FAST => nothing */
    0,  /*       SLOW => nothing */
    0,  /*    NODELAY => nothing */
    0,  /*   CANRAISE => nothing */
    0,  /*     OFFSET => nothing */
    0,  /*      LIGHT => nothing */
   54,  /*      SBYTE => IDENTIFIER */
   54,  /*       BYTE => IDENTIFIER */
   54,  /*      SHORT => IDENTIFIER */
   54,  /*     USHORT => IDENTIFIER */
   54,  /*        INT => IDENTIFIER */
   54,  /*       UINT => IDENTIFIER */
   54,  /*       BOOL => IDENTIFIER */
   54,  /*      FLOAT => IDENTIFIER */
   54,  /*     DOUBLE => IDENTIFIER */
   54,  /*    VECTOR2 => IDENTIFIER */
   54,  /*    VECTOR3 => IDENTIFIER */
   54,  /*       NAME => IDENTIFIER */
   54,  /*      SOUND => IDENTIFIER */
   54,  /*      STATE => IDENTIFIER */
    0,  /*        LET => nothing */
    0,  /*     ATSIGN => nothing */
    0,  /*   READONLY => nothing */
   54,  /*     STRING => IDENTIFIER */
   54,  /*        MAP => IDENTIFIER */
   54,  /*      ARRAY => IDENTIFIER */
   54,  /*       VOID => IDENTIFIER */
   54,  /*      UINT8 => IDENTIFIER */
   54,  /*       INT8 => IDENTIFIER */
   54,  /*     UINT16 => IDENTIFIER */
   54,  /*      INT16 => IDENTIFIER */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  ZCCParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "EQ",            "MULEQ",         "DIVEQ",       
  "MODEQ",         "ADDEQ",         "SUBEQ",         "LSHEQ",       
  "RSHEQ",         "ANDEQ",         "OREQ",          "XOREQ",       
  "URSHEQ",        "QUESTION",      "COLON",         "OROR",        
  "ANDAND",        "EQEQ",          "NEQ",           "APPROXEQ",    
  "LT",            "GT",            "LTEQ",          "GTEQ",        
  "LTGTEQ",        "IS",            "DOTDOT",        "OR",          
  "XOR",           "AND",           "LSH",           "RSH",         
  "URSH",          "SUB",           "ADD",           "MUL",         
  "DIV",           "MOD",           "CROSSPROD",     "DOTPROD",     
  "POW",           "UNARY",         "ADDADD",        "SUBSUB",      
  "DOT",           "LPAREN",        "LBRACKET",      "SCOPE",       
  "EOF",           "SEMICOLON",     "COMMA",         "INCLUDE",     
  "EXTEND",        "CLASS",         "IDENTIFIER",    "ABSTRACT",    
  "NATIVE",        "UI",            "PLAY",          "REPLACES",    
  "VERSION",       "STRCONST",      "RPAREN",        "DEFAULT",     
  "COLOR",         "LBRACE",        "RBRACE",        "MIXIN",       
  "PROPERTY",      "FLAGDEF",       "INTCONST",      "STRUCT",      
  "CLEARSCOPE",    "CONST",         "ENUM",          "STATES",      
  "NWS",           "STOP",          "WAIT",          "FAIL",        
  "LOOP",          "GOTO",          "SUPER",         "BRIGHT",      
  "FAST",          "SLOW",          "NODELAY",       "CANRAISE",    
  "OFFSET",        "LIGHT",         "SBYTE",         "BYTE",        
  "SHORT",         "USHORT",        "INT",           "UINT",        
  "BOOL",          "FLOAT",         "DOUBLE",        "VECTOR2",     
  "VECTOR3",       "NAME",          "SOUND",         "STATE",       
  "LET",           "ATSIGN",        "READONLY",      "STRING",      
  "MAP",           "ARRAY",         "VOID",          "UINT8",       
  "INT8",          "UINT16",        "INT16",         "RBRACKET",    
  "ACTION",        "DEPRECATED",    "STATIC",        "PRIVATE",     
  "PROTECTED",     "LATENT",        "FINAL",         "META",        
  "TRANSIENT",     "INTERNAL",      "VIRTUAL",       "OVERRIDE",    
  "VARARG",        "VIRTUALSCOPE",  "ELLIPSIS",      "IN",          
  "OUT",           "OPTIONAL",      "TILDE",         "BANG",        
  "SIZEOF",        "ALIGNOF",       "UINTCONST",     "FLOATCONST",  
  "NAMECONST",     "FALSE",         "TRUE",          "NULLPTR",     
  "STATICCONST",   "CONTINUE",      "BREAK",         "RETURN",      
  "DO",            "FOR",           "WHILE",         "UNTIL",       
  "IF",            "ELSE",          "SWITCH",        "CASE",        
  "error",         "declarator",    "declarator_no_fun",  "opt_func_body",
  "function_body",  "main",          "translation_unit",  "external_declaration",
  "mixin_definition",  "class_definition",  "struct_def",    "enum_def",    
  "const_def",     "include_def",   "opt_semicolon",  "opt_comma",   
  "opt_expr",      "expr",          "string_constant",  "class_head",  
  "class_innards",  "class_member",  "class_body",    "class_ancestry",
  "class_flags",   "dottable_id",   "mixin_statement",  "property_def",
  "flag_def",      "states_def",    "default_def",   "staticarray_statement",
  "opt_struct_body",  "struct_body",   "struct_member",  "identifier_list",
  "states_opt",    "struct_flags",  "enum_list",     "opt_enum_list",
  "enumerator",    "enum_type",     "int_type",      "mixin_class_definition",
  "mixin_class_body",  "mixin_class_member",  "states_body",   "state_line",  
  "state_label",   "state_flow",    "state_flow_type",  "state_goto_offset",
  "state_action",  "state_call",    "state_call_params",  "state_opts",  
  "states_opts",   "scanner_mode",  "light_list",    "statement_list",
  "func_expr_list",  "default_statement_list",  "default_statement",  "property_statement",
  "flag_statement",  "expr_list",     "type_name",     "type_name1",  
  "aggregate_type",  "type",          "type_list",     "type_list_or_void",
  "type_or_array",  "class_restrictor",  "array_size",    "array_size_expr",
  "variables_or_function",  "decl_flags",    "func_params",   "func_const",  
  "variable_list",  "variable_name",  "decl_flag",     "opt_deprecation_message",
  "func_param_list",  "func_param",    "func_param_flags",  "primary",     
  "unary_expr",    "constant",      "func_expr_item",  "named_expr",  
  "compound_statement",  "statement",     "labeled_statement",  "expression_statement",
  "selection_statement",  "iteration_statement",  "jump_statement",  "assign_statement",
  "local_var",     "while_or_until",  "for_init",      "for_bump",    
  "if_front",      "variable_list_with_init",  "var_init",    
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "translation_unit ::= error",
 /*   4 */ "external_declaration ::= mixin_definition",
 /*   5 */ "external_declaration ::= class_definition",
 /*   6 */ "external_declaration ::= struct_def",
 /*   7 */ "external_declaration ::= enum_def",
 /*   8 */ "external_declaration ::= const_def",
 /*   9 */ "external_declaration ::= include_def",
 /*  10 */ "opt_expr ::=",
 /*  11 */ "include_def ::= INCLUDE string_constant",
 /*  12 */ "class_definition ::= class_head class_body",
 /*  13 */ "class_head ::= EXTEND CLASS IDENTIFIER",
 /*  14 */ "class_head ::= CLASS IDENTIFIER class_ancestry class_flags",
 /*  15 */ "class_ancestry ::=",
 /*  16 */ "class_ancestry ::= COLON dottable_id",
 /*  17 */ "class_flags ::=",
 /*  18 */ "class_flags ::= class_flags ABSTRACT",
 /*  19 */ "class_flags ::= class_flags NATIVE",
 /*  20 */ "class_flags ::= class_flags UI",
 /*  21 */ "class_flags ::= class_flags PLAY",
 /*  22 */ "class_flags ::= class_flags REPLACES dottable_id",
 /*  23 */ "class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN",
 /*  24 */ "dottable_id ::= IDENTIFIER",
 /*  25 */ "dottable_id ::= dottable_id DOT IDENTIFIER",
 /*  26 */ "dottable_id ::= dottable_id DOT DEFAULT",
 /*  27 */ "dottable_id ::= dottable_id DOT COLOR",
 /*  28 */ "class_body ::= SEMICOLON class_innards EOF",
 /*  29 */ "class_body ::= LBRACE class_innards RBRACE",
 /*  30 */ "class_innards ::=",
 /*  31 */ "class_innards ::= class_innards class_member",
 /*  32 */ "class_member ::= declarator",
 /*  33 */ "class_member ::= mixin_statement",
 /*  34 */ "class_member ::= enum_def",
 /*  35 */ "class_member ::= struct_def",
 /*  36 */ "class_member ::= states_def",
 /*  37 */ "class_member ::= default_def",
 /*  38 */ "class_member ::= const_def",
 /*  39 */ "class_member ::= property_def",
 /*  40 */ "class_member ::= flag_def",
 /*  41 */ "class_member ::= staticarray_statement",
 /*  42 */ "mixin_statement ::= MIXIN IDENTIFIER SEMICOLON",
 /*  43 */ "property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON",
 /*  44 */ "flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON",
 /*  45 */ "identifier_list ::= IDENTIFIER",
 /*  46 */ "identifier_list ::= states_opt COMMA IDENTIFIER",
 /*  47 */ "struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  48 */ "struct_def ::= EXTEND STRUCT IDENTIFIER LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  49 */ "struct_flags ::=",
 /*  50 */ "struct_flags ::= struct_flags UI",
 /*  51 */ "struct_flags ::= struct_flags PLAY",
 /*  52 */ "struct_flags ::= struct_flags CLEARSCOPE",
 /*  53 */ "struct_flags ::= struct_flags NATIVE",
 /*  54 */ "struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN",
 /*  55 */ "opt_struct_body ::=",
 /*  56 */ "opt_struct_body ::= error",
 /*  57 */ "struct_body ::= struct_body struct_member",
 /*  58 */ "struct_member ::= declarator",
 /*  59 */ "struct_member ::= enum_def",
 /*  60 */ "struct_member ::= const_def",
 /*  61 */ "struct_member ::= staticarray_statement",
 /*  62 */ "const_def ::= CONST IDENTIFIER EQ expr SEMICOLON",
 /*  63 */ "enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon",
 /*  64 */ "enum_type ::=",
 /*  65 */ "enum_type ::= COLON int_type",
 /*  66 */ "enum_list ::= error",
 /*  67 */ "enum_list ::= enum_list COMMA enumerator",
 /*  68 */ "opt_enum_list ::=",
 /*  69 */ "enumerator ::= IDENTIFIER",
 /*  70 */ "enumerator ::= IDENTIFIER EQ expr",
 /*  71 */ "mixin_definition ::= mixin_class_definition",
 /*  72 */ "mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE",
 /*  73 */ "mixin_class_body ::=",
 /*  74 */ "mixin_class_body ::= mixin_class_body mixin_class_member",
 /*  75 */ "mixin_class_member ::= declarator",
 /*  76 */ "mixin_class_member ::= enum_def",
 /*  77 */ "mixin_class_member ::= struct_def",
 /*  78 */ "mixin_class_member ::= states_def",
 /*  79 */ "mixin_class_member ::= default_def",
 /*  80 */ "mixin_class_member ::= const_def",
 /*  81 */ "mixin_class_member ::= property_def",
 /*  82 */ "mixin_class_member ::= flag_def",
 /*  83 */ "mixin_class_member ::= staticarray_statement",
 /*  84 */ "states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE",
 /*  85 */ "states_opts ::=",
 /*  86 */ "states_opts ::= LPAREN states_opt RPAREN",
 /*  87 */ "states_opt ::= IDENTIFIER",
 /*  88 */ "states_opt ::= states_opt COMMA IDENTIFIER",
 /*  89 */ "scanner_mode ::=",
 /*  90 */ "states_body ::=",
 /*  91 */ "states_body ::= error",
 /*  92 */ "states_body ::= states_body state_line",
 /*  93 */ "states_body ::= states_body state_label",
 /*  94 */ "states_body ::= states_body state_flow",
 /*  95 */ "state_label ::= NWS COLON",
 /*  96 */ "state_flow_type ::= STOP",
 /*  97 */ "state_flow_type ::= WAIT",
 /*  98 */ "state_flow_type ::= FAIL",
 /*  99 */ "state_flow_type ::= LOOP",
 /* 100 */ "state_flow_type ::= GOTO dottable_id state_goto_offset",
 /* 101 */ "state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset",
 /* 102 */ "state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset",
 /* 103 */ "state_goto_offset ::=",
 /* 104 */ "state_goto_offset ::= ADD expr",
 /* 105 */ "state_line ::= NWS NWS expr state_opts state_action",
 /* 106 */ "state_opts ::=",
 /* 107 */ "state_opts ::= state_opts BRIGHT",
 /* 108 */ "state_opts ::= state_opts FAST",
 /* 109 */ "state_opts ::= state_opts SLOW",
 /* 110 */ "state_opts ::= state_opts NODELAY",
 /* 111 */ "state_opts ::= state_opts CANRAISE",
 /* 112 */ "state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN",
 /* 113 */ "state_opts ::= state_opts LIGHT LPAREN light_list RPAREN",
 /* 114 */ "light_list ::= STRCONST",
 /* 115 */ "light_list ::= light_list COMMA STRCONST",
 /* 116 */ "state_action ::= LBRACE statement_list scanner_mode RBRACE",
 /* 117 */ "state_action ::= LBRACE scanner_mode RBRACE",
 /* 118 */ "state_action ::= LBRACE error scanner_mode RBRACE",
 /* 119 */ "state_action ::= state_call scanner_mode SEMICOLON",
 /* 120 */ "state_call ::=",
 /* 121 */ "state_call ::= IDENTIFIER state_call_params",
 /* 122 */ "state_call_params ::=",
 /* 123 */ "state_call_params ::= LPAREN func_expr_list RPAREN",
 /* 124 */ "default_def ::= DEFAULT LBRACE RBRACE",
 /* 125 */ "default_def ::= DEFAULT LBRACE default_statement_list RBRACE",
 /* 126 */ "default_def ::= DEFAULT LBRACE error RBRACE",
 /* 127 */ "default_statement_list ::= default_statement",
 /* 128 */ "default_statement_list ::= default_statement_list default_statement",
 /* 129 */ "default_statement ::= SEMICOLON",
 /* 130 */ "default_statement ::= error SEMICOLON",
 /* 131 */ "default_statement ::= property_statement",
 /* 132 */ "default_statement ::= flag_statement",
 /* 133 */ "flag_statement ::= ADD dottable_id",
 /* 134 */ "flag_statement ::= SUB dottable_id",
 /* 135 */ "property_statement ::= dottable_id expr_list SEMICOLON",
 /* 136 */ "property_statement ::= dottable_id SEMICOLON",
 /* 137 */ "int_type ::= SBYTE",
 /* 138 */ "int_type ::= BYTE",
 /* 139 */ "int_type ::= SHORT",
 /* 140 */ "int_type ::= USHORT",
 /* 141 */ "int_type ::= INT",
 /* 142 */ "int_type ::= UINT",
 /* 143 */ "type_name1 ::= BOOL",
 /* 144 */ "type_name1 ::= FLOAT",
 /* 145 */ "type_name1 ::= DOUBLE",
 /* 146 */ "type_name1 ::= VECTOR2",
 /* 147 */ "type_name1 ::= VECTOR3",
 /* 148 */ "type_name1 ::= NAME",
 /* 149 */ "type_name1 ::= SOUND",
 /* 150 */ "type_name1 ::= STATE",
 /* 151 */ "type_name1 ::= COLOR",
 /* 152 */ "type_name1 ::= LET",
 /* 153 */ "type_name ::= type_name1",
 /* 154 */ "type_name ::= IDENTIFIER",
 /* 155 */ "type_name ::= ATSIGN IDENTIFIER",
 /* 156 */ "type_name ::= READONLY LT IDENTIFIER GT",
 /* 157 */ "type_name ::= READONLY LT ATSIGN IDENTIFIER GT",
 /* 158 */ "type_name ::= DOT dottable_id",
 /* 159 */ "aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT",
 /* 160 */ "aggregate_type ::= ARRAY LT type_or_array GT",
 /* 161 */ "aggregate_type ::= CLASS class_restrictor",
 /* 162 */ "class_restrictor ::=",
 /* 163 */ "class_restrictor ::= LT dottable_id GT",
 /* 164 */ "type ::= type_name",
 /* 165 */ "type ::= aggregate_type",
 /* 166 */ "type_or_array ::= type array_size",
 /* 167 */ "type_list ::= type_list COMMA type_or_array",
 /* 168 */ "type_list_or_void ::= VOID",
 /* 169 */ "array_size_expr ::= LBRACKET opt_expr RBRACKET",
 /* 170 */ "array_size ::= array_size array_size_expr",
 /* 171 */ "declarator ::= decl_flags type_list_or_void variables_or_function",
 /* 172 */ "variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body",
 /* 173 */ "variables_or_function ::= variable_list SEMICOLON",
 /* 174 */ "variables_or_function ::= error SEMICOLON",
 /* 175 */ "variable_name ::= IDENTIFIER",
 /* 176 */ "variable_name ::= IDENTIFIER array_size",
 /* 177 */ "variable_list ::= variable_list COMMA variable_name",
 /* 178 */ "decl_flags ::=",
 /* 179 */ "decl_flags ::= decl_flags decl_flag",
 /* 180 */ "decl_flags ::= decl_flags ACTION states_opts",
 /* 181 */ "opt_deprecation_message ::=",
 /* 182 */ "opt_deprecation_message ::= COMMA STRCONST",
 /* 183 */ "decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN",
 /* 184 */ "decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN",
 /* 185 */ "decl_flag ::= NATIVE",
 /* 186 */ "decl_flag ::= STATIC",
 /* 187 */ "decl_flag ::= PRIVATE",
 /* 188 */ "decl_flag ::= PROTECTED",
 /* 189 */ "decl_flag ::= LATENT",
 /* 190 */ "decl_flag ::= FINAL",
 /* 191 */ "decl_flag ::= META",
 /* 192 */ "decl_flag ::= TRANSIENT",
 /* 193 */ "decl_flag ::= READONLY",
 /* 194 */ "decl_flag ::= INTERNAL",
 /* 195 */ "decl_flag ::= VIRTUAL",
 /* 196 */ "decl_flag ::= OVERRIDE",
 /* 197 */ "decl_flag ::= ABSTRACT",
 /* 198 */ "decl_flag ::= VARARG",
 /* 199 */ "decl_flag ::= UI",
 /* 200 */ "decl_flag ::= PLAY",
 /* 201 */ "decl_flag ::= CLEARSCOPE",
 /* 202 */ "decl_flag ::= VIRTUALSCOPE",
 /* 203 */ "func_const ::=",
 /* 204 */ "func_const ::= CONST",
 /* 205 */ "opt_func_body ::= SEMICOLON",
 /* 206 */ "func_params ::=",
 /* 207 */ "func_params ::= VOID",
 /* 208 */ "func_params ::= func_param_list COMMA ELLIPSIS",
 /* 209 */ "func_param_list ::= func_param_list COMMA func_param",
 /* 210 */ "func_param ::= func_param_flags type IDENTIFIER",
 /* 211 */ "func_param ::= func_param_flags type IDENTIFIER EQ expr",
 /* 212 */ "func_param_flags ::=",
 /* 213 */ "func_param_flags ::= func_param_flags IN",
 /* 214 */ "func_param_flags ::= func_param_flags OUT",
 /* 215 */ "func_param_flags ::= func_param_flags OPTIONAL",
 /* 216 */ "primary ::= IDENTIFIER",
 /* 217 */ "primary ::= SUPER",
 /* 218 */ "primary ::= constant",
 /* 219 */ "primary ::= LPAREN expr COMMA expr COMMA expr RPAREN",
 /* 220 */ "primary ::= LPAREN expr COMMA expr RPAREN",
 /* 221 */ "primary ::= LPAREN expr RPAREN",
 /* 222 */ "primary ::= primary LPAREN func_expr_list RPAREN",
 /* 223 */ "primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN",
 /* 224 */ "primary ::= primary LBRACKET expr RBRACKET",
 /* 225 */ "primary ::= primary DOT IDENTIFIER",
 /* 226 */ "primary ::= primary ADDADD",
 /* 227 */ "primary ::= primary SUBSUB",
 /* 228 */ "unary_expr ::= SUB unary_expr",
 /* 229 */ "unary_expr ::= ADD unary_expr",
 /* 230 */ "unary_expr ::= SUBSUB unary_expr",
 /* 231 */ "unary_expr ::= ADDADD unary_expr",
 /* 232 */ "unary_expr ::= TILDE unary_expr",
 /* 233 */ "unary_expr ::= BANG unary_expr",
 /* 234 */ "unary_expr ::= SIZEOF unary_expr",
 /* 235 */ "unary_expr ::= ALIGNOF unary_expr",
 /* 236 */ "expr ::= expr ADD expr",
 /* 237 */ "expr ::= expr SUB expr",
 /* 238 */ "expr ::= expr MUL expr",
 /* 239 */ "expr ::= expr DIV expr",
 /* 240 */ "expr ::= expr MOD expr",
 /* 241 */ "expr ::= expr POW expr",
 /* 242 */ "expr ::= expr CROSSPROD expr",
 /* 243 */ "expr ::= expr DOTPROD expr",
 /* 244 */ "expr ::= expr LSH expr",
 /* 245 */ "expr ::= expr RSH expr",
 /* 246 */ "expr ::= expr URSH expr",
 /* 247 */ "expr ::= expr DOTDOT expr",
 /* 248 */ "expr ::= expr LT expr",
 /* 249 */ "expr ::= expr GT expr",
 /* 250 */ "expr ::= expr LTEQ expr",
 /* 251 */ "expr ::= expr GTEQ expr",
 /* 252 */ "expr ::= expr LTGTEQ expr",
 /* 253 */ "expr ::= expr IS expr",
 /* 254 */ "expr ::= expr EQEQ expr",
 /* 255 */ "expr ::= expr NEQ expr",
 /* 256 */ "expr ::= expr APPROXEQ expr",
 /* 257 */ "expr ::= expr AND expr",
 /* 258 */ "expr ::= expr XOR expr",
 /* 259 */ "expr ::= expr OR expr",
 /* 260 */ "expr ::= expr ANDAND expr",
 /* 261 */ "expr ::= expr OROR expr",
 /* 262 */ "expr ::= expr EQ expr",
 /* 263 */ "expr ::= expr ADDEQ expr",
 /* 264 */ "expr ::= expr SUBEQ expr",
 /* 265 */ "expr ::= expr MULEQ expr",
 /* 266 */ "expr ::= expr DIVEQ expr",
 /* 267 */ "expr ::= expr MODEQ expr",
 /* 268 */ "expr ::= expr LSHEQ expr",
 /* 269 */ "expr ::= expr RSHEQ expr",
 /* 270 */ "expr ::= expr URSHEQ expr",
 /* 271 */ "expr ::= expr ANDEQ expr",
 /* 272 */ "expr ::= expr OREQ expr",
 /* 273 */ "expr ::= expr XOREQ expr",
 /* 274 */ "expr ::= expr SCOPE expr",
 /* 275 */ "expr ::= expr QUESTION expr COLON expr",
 /* 276 */ "expr_list ::= expr_list COMMA expr",
 /* 277 */ "func_expr_list ::= func_expr_list COMMA func_expr_item",
 /* 278 */ "func_expr_item ::=",
 /* 279 */ "named_expr ::= IDENTIFIER COLON expr",
 /* 280 */ "named_expr ::= expr",
 /* 281 */ "string_constant ::= STRCONST",
 /* 282 */ "string_constant ::= string_constant STRCONST",
 /* 283 */ "constant ::= INTCONST",
 /* 284 */ "constant ::= UINTCONST",
 /* 285 */ "constant ::= FLOATCONST",
 /* 286 */ "constant ::= NAMECONST",
 /* 287 */ "constant ::= FALSE",
 /* 288 */ "constant ::= TRUE",
 /* 289 */ "constant ::= NULLPTR",
 /* 290 */ "statement ::= SEMICOLON",
 /* 291 */ "statement ::= labeled_statement",
 /* 292 */ "statement ::= compound_statement",
 /* 293 */ "statement ::= expression_statement SEMICOLON",
 /* 294 */ "statement ::= assign_statement SEMICOLON",
 /* 295 */ "statement ::= local_var SEMICOLON",
 /* 296 */ "statement ::= error SEMICOLON",
 /* 297 */ "statement ::= staticarray_statement",
 /* 298 */ "staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 299 */ "staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 300 */ "jump_statement ::= CONTINUE SEMICOLON",
 /* 301 */ "jump_statement ::= BREAK SEMICOLON",
 /* 302 */ "jump_statement ::= RETURN SEMICOLON",
 /* 303 */ "jump_statement ::= RETURN expr_list SEMICOLON",
 /* 304 */ "compound_statement ::= LBRACE RBRACE",
 /* 305 */ "compound_statement ::= LBRACE statement_list RBRACE",
 /* 306 */ "compound_statement ::= LBRACE error RBRACE",
 /* 307 */ "statement_list ::= statement",
 /* 308 */ "statement_list ::= statement_list statement",
 /* 309 */ "expression_statement ::= expr",
 /* 310 */ "iteration_statement ::= while_or_until LPAREN expr RPAREN statement",
 /* 311 */ "iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN",
 /* 312 */ "iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement",
 /* 313 */ "while_or_until ::= WHILE",
 /* 314 */ "while_or_until ::= UNTIL",
 /* 315 */ "for_init ::= local_var",
 /* 316 */ "for_init ::= for_bump",
 /* 317 */ "for_bump ::=",
 /* 318 */ "for_bump ::= expression_statement",
 /* 319 */ "for_bump ::= for_bump COMMA expression_statement",
 /* 320 */ "selection_statement ::= if_front",
 /* 321 */ "selection_statement ::= if_front ELSE statement",
 /* 322 */ "if_front ::= IF LPAREN expr RPAREN statement",
 /* 323 */ "selection_statement ::= SWITCH LPAREN expr RPAREN statement",
 /* 324 */ "labeled_statement ::= CASE expr COLON",
 /* 325 */ "labeled_statement ::= DEFAULT COLON",
 /* 326 */ "assign_statement ::= LBRACKET expr_list RBRACKET EQ expr",
 /* 327 */ "local_var ::= type variable_list_with_init",
 /* 328 */ "var_init ::= IDENTIFIER",
 /* 329 */ "var_init ::= IDENTIFIER array_size",
 /* 330 */ "var_init ::= IDENTIFIER EQ expr",
 /* 331 */ "var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE",
 /* 332 */ "var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE",
 /* 333 */ "var_init ::= IDENTIFIER EQ LBRACE error RBRACE",
 /* 334 */ "variable_list_with_init ::= variable_list_with_init COMMA var_init",
 /* 335 */ "translation_unit ::= translation_unit EOF",
 /* 336 */ "opt_semicolon ::=",
 /* 337 */ "opt_semicolon ::= SEMICOLON",
 /* 338 */ "opt_comma ::=",
 /* 339 */ "opt_comma ::= COMMA",
 /* 340 */ "opt_expr ::= expr",
 /* 341 */ "opt_struct_body ::= struct_body",
 /* 342 */ "struct_body ::= struct_member",
 /* 343 */ "enum_list ::= enumerator",
 /* 344 */ "opt_enum_list ::= enum_list opt_comma",
 /* 345 */ "state_flow ::= state_flow_type scanner_mode SEMICOLON",
 /* 346 */ "type_name1 ::= int_type",
 /* 347 */ "type_or_array ::= type",
 /* 348 */ "type_list ::= type_or_array",
 /* 349 */ "type_list_or_void ::= type_list",
 /* 350 */ "array_size ::= array_size_expr",
 /* 351 */ "variable_list ::= variable_name",
 /* 352 */ "opt_func_body ::= function_body",
 /* 353 */ "func_params ::= func_param_list",
 /* 354 */ "func_param_list ::= func_param",
 /* 355 */ "primary ::= LPAREN error RPAREN",
 /* 356 */ "unary_expr ::= primary",
 /* 357 */ "expr ::= unary_expr",
 /* 358 */ "expr_list ::= expr",
 /* 359 */ "func_expr_list ::= func_expr_item",
 /* 360 */ "func_expr_item ::= named_expr",
 /* 361 */ "constant ::= string_constant",
 /* 362 */ "function_body ::= compound_statement",
 /* 363 */ "statement ::= selection_statement",
 /* 364 */ "statement ::= iteration_statement",
 /* 365 */ "statement ::= jump_statement",
 /* 366 */ "variable_list_with_init ::= var_init",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = (yyStackEntry *)malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = (yyStackEntry *)realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
      fflush(yyTraceFILE);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to ZCCParseAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to ZCCParse and ZCCParseFree.
*/
void *ZCCParseAlloc(void *(CDECL *mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ZCCParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
      /* TERMINAL Destructor */
    case 1: /* EQ */
    case 2: /* MULEQ */
    case 3: /* DIVEQ */
    case 4: /* MODEQ */
    case 5: /* ADDEQ */
    case 6: /* SUBEQ */
    case 7: /* LSHEQ */
    case 8: /* RSHEQ */
    case 9: /* ANDEQ */
    case 10: /* OREQ */
    case 11: /* XOREQ */
    case 12: /* URSHEQ */
    case 13: /* QUESTION */
    case 14: /* COLON */
    case 15: /* OROR */
    case 16: /* ANDAND */
    case 17: /* EQEQ */
    case 18: /* NEQ */
    case 19: /* APPROXEQ */
    case 20: /* LT */
    case 21: /* GT */
    case 22: /* LTEQ */
    case 23: /* GTEQ */
    case 24: /* LTGTEQ */
    case 25: /* IS */
    case 26: /* DOTDOT */
    case 27: /* OR */
    case 28: /* XOR */
    case 29: /* AND */
    case 30: /* LSH */
    case 31: /* RSH */
    case 32: /* URSH */
    case 33: /* SUB */
    case 34: /* ADD */
    case 35: /* MUL */
    case 36: /* DIV */
    case 37: /* MOD */
    case 38: /* CROSSPROD */
    case 39: /* DOTPROD */
    case 40: /* POW */
    case 41: /* UNARY */
    case 42: /* ADDADD */
    case 43: /* SUBSUB */
    case 44: /* DOT */
    case 45: /* LPAREN */
    case 46: /* LBRACKET */
    case 47: /* SCOPE */
    case 48: /* EOF */
    case 49: /* SEMICOLON */
    case 50: /* COMMA */
    case 51: /* INCLUDE */
    case 52: /* EXTEND */
    case 53: /* CLASS */
    case 54: /* IDENTIFIER */
    case 55: /* ABSTRACT */
    case 56: /* NATIVE */
    case 57: /* UI */
    case 58: /* PLAY */
    case 59: /* REPLACES */
    case 60: /* VERSION */
    case 61: /* STRCONST */
    case 62: /* RPAREN */
    case 63: /* DEFAULT */
    case 64: /* COLOR */
    case 65: /* LBRACE */
    case 66: /* RBRACE */
    case 67: /* MIXIN */
    case 68: /* PROPERTY */
    case 69: /* FLAGDEF */
    case 70: /* INTCONST */
    case 71: /* STRUCT */
    case 72: /* CLEARSCOPE */
    case 73: /* CONST */
    case 74: /* ENUM */
    case 75: /* STATES */
    case 76: /* NWS */
    case 77: /* STOP */
    case 78: /* WAIT */
    case 79: /* FAIL */
    case 80: /* LOOP */
    case 81: /* GOTO */
    case 82: /* SUPER */
    case 83: /* BRIGHT */
    case 84: /* FAST */
    case 85: /* SLOW */
    case 86: /* NODELAY */
    case 87: /* CANRAISE */
    case 88: /* OFFSET */
    case 89: /* LIGHT */
    case 90: /* SBYTE */
    case 91: /* BYTE */
    case 92: /* SHORT */
    case 93: /* USHORT */
    case 94: /* INT */
    case 95: /* UINT */
    case 96: /* BOOL */
    case 97: /* FLOAT */
    case 98: /* DOUBLE */
    case 99: /* VECTOR2 */
    case 100: /* VECTOR3 */
    case 101: /* NAME */
    case 102: /* SOUND */
    case 103: /* STATE */
    case 104: /* LET */
    case 105: /* ATSIGN */
    case 106: /* READONLY */
    case 107: /* STRING */
    case 108: /* MAP */
    case 109: /* ARRAY */
    case 110: /* VOID */
    case 111: /* UINT8 */
    case 112: /* INT8 */
    case 113: /* UINT16 */
    case 114: /* INT16 */
    case 115: /* RBRACKET */
    case 116: /* ACTION */
    case 117: /* DEPRECATED */
    case 118: /* STATIC */
    case 119: /* PRIVATE */
    case 120: /* PROTECTED */
    case 121: /* LATENT */
    case 122: /* FINAL */
    case 123: /* META */
    case 124: /* TRANSIENT */
    case 125: /* INTERNAL */
    case 126: /* VIRTUAL */
    case 127: /* OVERRIDE */
    case 128: /* VARARG */
    case 129: /* VIRTUALSCOPE */
    case 130: /* ELLIPSIS */
    case 131: /* IN */
    case 132: /* OUT */
    case 133: /* OPTIONAL */
    case 134: /* TILDE */
    case 135: /* BANG */
    case 136: /* SIZEOF */
    case 137: /* ALIGNOF */
    case 138: /* UINTCONST */
    case 139: /* FLOATCONST */
    case 140: /* NAMECONST */
    case 141: /* FALSE */
    case 142: /* TRUE */
    case 143: /* NULLPTR */
    case 144: /* STATICCONST */
    case 145: /* CONTINUE */
    case 146: /* BREAK */
    case 147: /* RETURN */
    case 148: /* DO */
    case 149: /* FOR */
    case 150: /* WHILE */
    case 151: /* UNTIL */
    case 152: /* IF */
    case 153: /* ELSE */
    case 154: /* SWITCH */
    case 155: /* CASE */
{
#line 117 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"

#line 1901 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
    fflush(yyTraceFILE);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void ZCCParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ZCCParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
          fflush(yyTraceFILE);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
            fflush(yyTraceFILE);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   ZCCParseARG_FETCH;
   yypParser->yytos--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     fflush(yyTraceFILE);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
    fflush(yyTraceFILE);
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  ZCCParseTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 161, 1 },
  { 162, 0 },
  { 162, 2 },
  { 162, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 172, 0 },
  { 169, 2 },
  { 165, 2 },
  { 175, 3 },
  { 175, 4 },
  { 179, 0 },
  { 179, 2 },
  { 180, 0 },
  { 180, 2 },
  { 180, 2 },
  { 180, 2 },
  { 180, 2 },
  { 180, 3 },
  { 180, 5 },
  { 181, 1 },
  { 181, 3 },
  { 181, 3 },
  { 181, 3 },
  { 178, 3 },
  { 178, 3 },
  { 176, 0 },
  { 176, 2 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 182, 3 },
  { 183, 5 },
  { 184, 7 },
  { 191, 1 },
  { 191, 3 },
  { 166, 7 },
  { 166, 7 },
  { 193, 0 },
  { 193, 2 },
  { 193, 2 },
  { 193, 2 },
  { 193, 2 },
  { 193, 5 },
  { 188, 0 },
  { 188, 1 },
  { 189, 2 },
  { 190, 1 },
  { 190, 1 },
  { 190, 1 },
  { 190, 1 },
  { 168, 5 },
  { 167, 7 },
  { 197, 0 },
  { 197, 2 },
  { 194, 1 },
  { 194, 3 },
  { 195, 0 },
  { 196, 1 },
  { 196, 3 },
  { 164, 1 },
  { 199, 6 },
  { 200, 0 },
  { 200, 2 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 185, 6 },
  { 212, 0 },
  { 212, 3 },
  { 192, 1 },
  { 192, 3 },
  { 213, 0 },
  { 202, 0 },
  { 202, 1 },
  { 202, 2 },
  { 202, 2 },
  { 202, 2 },
  { 204, 2 },
  { 206, 1 },
  { 206, 1 },
  { 206, 1 },
  { 206, 1 },
  { 206, 3 },
  { 206, 5 },
  { 206, 5 },
  { 207, 0 },
  { 207, 2 },
  { 203, 5 },
  { 211, 0 },
  { 211, 2 },
  { 211, 2 },
  { 211, 2 },
  { 211, 2 },
  { 211, 2 },
  { 211, 7 },
  { 211, 5 },
  { 214, 1 },
  { 214, 3 },
  { 208, 4 },
  { 208, 3 },
  { 208, 4 },
  { 208, 3 },
  { 209, 0 },
  { 209, 2 },
  { 210, 0 },
  { 210, 3 },
  { 186, 3 },
  { 186, 4 },
  { 186, 4 },
  { 217, 1 },
  { 217, 2 },
  { 218, 1 },
  { 218, 2 },
  { 218, 1 },
  { 218, 1 },
  { 220, 2 },
  { 220, 2 },
  { 219, 3 },
  { 219, 2 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 222, 1 },
  { 222, 1 },
  { 222, 2 },
  { 222, 4 },
  { 222, 5 },
  { 222, 2 },
  { 224, 6 },
  { 224, 4 },
  { 224, 2 },
  { 229, 0 },
  { 229, 3 },
  { 225, 1 },
  { 225, 1 },
  { 228, 2 },
  { 226, 3 },
  { 227, 1 },
  { 231, 3 },
  { 230, 2 },
  { 157, 3 },
  { 232, 6 },
  { 232, 2 },
  { 232, 2 },
  { 237, 1 },
  { 237, 2 },
  { 236, 3 },
  { 233, 0 },
  { 233, 2 },
  { 233, 3 },
  { 239, 0 },
  { 239, 2 },
  { 233, 6 },
  { 233, 5 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 235, 0 },
  { 235, 1 },
  { 159, 1 },
  { 234, 0 },
  { 234, 1 },
  { 234, 3 },
  { 240, 3 },
  { 241, 3 },
  { 241, 5 },
  { 242, 0 },
  { 242, 2 },
  { 242, 2 },
  { 242, 2 },
  { 243, 1 },
  { 243, 1 },
  { 243, 1 },
  { 243, 7 },
  { 243, 5 },
  { 243, 3 },
  { 243, 4 },
  { 243, 9 },
  { 243, 4 },
  { 243, 3 },
  { 243, 2 },
  { 243, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 5 },
  { 221, 3 },
  { 216, 3 },
  { 246, 0 },
  { 247, 3 },
  { 247, 1 },
  { 174, 1 },
  { 174, 2 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 249, 1 },
  { 249, 1 },
  { 249, 1 },
  { 249, 2 },
  { 249, 2 },
  { 249, 2 },
  { 249, 2 },
  { 249, 1 },
  { 187, 10 },
  { 187, 10 },
  { 254, 2 },
  { 254, 2 },
  { 254, 2 },
  { 254, 3 },
  { 248, 2 },
  { 248, 3 },
  { 248, 3 },
  { 215, 1 },
  { 215, 2 },
  { 251, 1 },
  { 253, 5 },
  { 253, 6 },
  { 253, 9 },
  { 257, 1 },
  { 257, 1 },
  { 258, 1 },
  { 258, 1 },
  { 259, 0 },
  { 259, 1 },
  { 259, 3 },
  { 252, 1 },
  { 252, 3 },
  { 260, 5 },
  { 252, 5 },
  { 250, 3 },
  { 250, 2 },
  { 255, 5 },
  { 256, 2 },
  { 262, 1 },
  { 262, 2 },
  { 262, 3 },
  { 262, 5 },
  { 262, 6 },
  { 262, 5 },
  { 261, 3 },
  { 162, 2 },
  { 170, 0 },
  { 170, 1 },
  { 171, 0 },
  { 171, 1 },
  { 172, 1 },
  { 188, 1 },
  { 189, 1 },
  { 194, 1 },
  { 195, 2 },
  { 205, 3 },
  { 223, 1 },
  { 228, 1 },
  { 226, 1 },
  { 227, 1 },
  { 230, 1 },
  { 236, 1 },
  { 159, 1 },
  { 234, 1 },
  { 240, 1 },
  { 243, 3 },
  { 244, 1 },
  { 173, 1 },
  { 221, 1 },
  { 216, 1 },
  { 246, 1 },
  { 245, 1 },
  { 160, 1 },
  { 249, 1 },
  { 249, 1 },
  { 249, 1 },
  { 261, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ZCCParseARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
    fflush(yyTraceFILE);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* main ::= translation_unit */
#line 173 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ stat->TopNode = yymsp[0].minor.yy38; DPrintf(DMSG_SPAMMY, "Parse complete\n"); }
#line 2582 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 1: /* translation_unit ::= */
      case 30: /*class_innards ::= */ yytestcase(yyruleno==30);
      case 55: /*opt_struct_body ::= */ yytestcase(yyruleno==55);
      case 73: /*mixin_class_body ::= */ yytestcase(yyruleno==73);
#line 176 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy38 = NULL; }
#line 2590 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 2: /* translation_unit ::= translation_unit external_declaration */
      case 31: /*class_innards ::= class_innards class_member */ yytestcase(yyruleno==31);
      case 74: /*mixin_class_body ::= mixin_class_body mixin_class_member */ yytestcase(yyruleno==74);
#line 177 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy38,yymsp[0].minor.yy38); }
#line 2597 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 3: /* translation_unit ::= error */
      case 56: /*opt_struct_body ::= error */ yytestcase(yyruleno==56);
#line 179 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = NULL; }
#line 2603 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 4: /* external_declaration ::= mixin_definition */
#line 182 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy48; /*X-overwrites-A*/ }
#line 2608 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 5: /* external_declaration ::= class_definition */
#line 183 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy414; /*X-overwrites-A*/ }
#line 2613 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 6: /* external_declaration ::= struct_def */
      case 35: /*class_member ::= struct_def */ yytestcase(yyruleno==35);
      case 77: /*mixin_class_member ::= struct_def */ yytestcase(yyruleno==77);
#line 184 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy262; /*X-overwrites-A*/ }
#line 2620 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 7: /* external_declaration ::= enum_def */
      case 34: /*class_member ::= enum_def */ yytestcase(yyruleno==34);
      case 59: /*struct_member ::= enum_def */ yytestcase(yyruleno==59);
      case 76: /*mixin_class_member ::= enum_def */ yytestcase(yyruleno==76);
#line 185 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy245; /*X-overwrites-A*/ }
#line 2628 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 8: /* external_declaration ::= const_def */
      case 38: /*class_member ::= const_def */ yytestcase(yyruleno==38);
      case 60: /*struct_member ::= const_def */ yytestcase(yyruleno==60);
      case 80: /*mixin_class_member ::= const_def */ yytestcase(yyruleno==80);
#line 186 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy307; /*X-overwrites-A*/ }
#line 2636 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 9: /* external_declaration ::= include_def */
#line 187 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = nullptr; }
#line 2641 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 10: /* opt_expr ::= */
#line 198 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[1].minor.yy138 = NULL;
}
#line 2648 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 11: /* include_def ::= INCLUDE string_constant */
{  yy_destructor(yypParser,51,&yymsp[-1].minor);
#line 205 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	AddInclude(yymsp[0].minor.yy237);
}
#line 2656 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 12: /* class_definition ::= class_head class_body */
#line 219 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-1].minor.yy414->Body = yymsp[0].minor.yy38;
	yymsp[-1].minor.yy414 = yymsp[-1].minor.yy414; /*X-overwrites-A*/
}
#line 2665 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 13: /* class_head ::= EXTEND CLASS IDENTIFIER */
{  yy_destructor(yypParser,52,&yymsp[-2].minor);
#line 225 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-1].minor.yy0);
	head->NodeName = yymsp[0].minor.yy0.Name();
	head->ParentName = nullptr;
	head->Flags =  ZCC_Extension;
	head->Replaces = nullptr;
	head->Version = {0, 0};
	head->Type = nullptr;
	head->Symbol = nullptr;
	yymsp[-2].minor.yy414 = head;
}
#line 2681 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 14: /* class_head ::= CLASS IDENTIFIER class_ancestry class_flags */
#line 239 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-3].minor.yy0);
	head->NodeName = yymsp[-2].minor.yy0.Name();
	head->ParentName = yymsp[-1].minor.yy35;
	head->Flags = yymsp[0].minor.yy37.Flags;
	head->Replaces = yymsp[0].minor.yy37.Replaces;
	head->Version = yymsp[0].minor.yy37.Version;
	head->Type = nullptr;
	head->Symbol = nullptr;
	yylhsminor.yy414 = head;
}
#line 2697 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-3].minor.yy414 = yylhsminor.yy414;
        break;
      case 15: /* class_ancestry ::= */
      case 162: /*class_restrictor ::= */ yytestcase(yyruleno==162);
#line 252 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy35 = NULL; }
#line 2704 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 16: /* class_ancestry ::= COLON dottable_id */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 253 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy35 = yymsp[0].minor.yy35; /*yymsp[-1].minor.yy35-overwrites-yymsp[0].minor.yy35*/ }
#line 2710 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 17: /* class_flags ::= */
#line 256 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy37.Flags = 0; yymsp[1].minor.yy37.Replaces = NULL; yymsp[1].minor.yy37.Version = {0,0}; }
#line 2716 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 18: /* class_flags ::= class_flags ABSTRACT */
#line 257 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Abstract; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2721 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,55,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 19: /* class_flags ::= class_flags NATIVE */
#line 258 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Native; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2728 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 20: /* class_flags ::= class_flags UI */
#line 259 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_UIFlag; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2735 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 21: /* class_flags ::= class_flags PLAY */
#line 260 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Play; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2742 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 22: /* class_flags ::= class_flags REPLACES dottable_id */
#line 261 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-2].minor.yy37.Flags; yylhsminor.yy37.Replaces = yymsp[0].minor.yy35; }
#line 2749 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[-1].minor);
  yymsp[-2].minor.yy37 = yylhsminor.yy37;
        break;
      case 23: /* class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN */
#line 262 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-4].minor.yy37.Flags | ZCC_Version; yylhsminor.yy37.Replaces = yymsp[-4].minor.yy37.Replaces; yylhsminor.yy37.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2756 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy37 = yylhsminor.yy37;
        break;
      case 24: /* dottable_id ::= IDENTIFIER */
      case 45: /*identifier_list ::= IDENTIFIER */ yytestcase(yyruleno==45);
      case 87: /*states_opt ::= IDENTIFIER */ yytestcase(yyruleno==87);
#line 270 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy35 = id;
}
#line 2771 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy35 = yylhsminor.yy35;
        break;
      case 25: /* dottable_id ::= dottable_id DOT IDENTIFIER */
#line 276 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy35);
	id2->Id = yymsp[0].minor.yy0.Name();
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id2);
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
}
#line 2782 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
        break;
      case 26: /* dottable_id ::= dottable_id DOT DEFAULT */
#line 283 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy35);
	id2->Id = NAME_Default;
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id2);
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
}
#line 2793 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
        break;
      case 27: /* dottable_id ::= dottable_id DOT COLOR */
#line 294 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy35);
	id2->Id = NAME_Color;
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id2);
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
}
#line 2805 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,64,&yymsp[0].minor);
        break;
      case 28: /* class_body ::= SEMICOLON class_innards EOF */
{  yy_destructor(yypParser,49,&yymsp[-2].minor);
#line 311 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy38 = yymsp[-1].minor.yy38; /*yymsp[-2].minor.yy38-overwrites-yymsp[-1].minor.yy38*/ }
#line 2813 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
}
        break;
      case 29: /* class_body ::= LBRACE class_innards RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 312 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy38 = yymsp[-1].minor.yy38; /*yymsp[-2].minor.yy38-overwrites-yymsp[-1].minor.yy38*/ }
#line 2821 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 32: /* class_member ::= declarator */
      case 58: /*struct_member ::= declarator */ yytestcase(yyruleno==58);
      case 75: /*mixin_class_member ::= declarator */ yytestcase(yyruleno==75);
#line 325 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy243; /*X-overwrites-A*/ }
#line 2830 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 33: /* class_member ::= mixin_statement */
#line 326 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy523; /*X-overwrites-A*/ }
#line 2835 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 36: /* class_member ::= states_def */
      case 78: /*mixin_class_member ::= states_def */ yytestcase(yyruleno==78);
#line 329 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy276; /*X-overwrites-A*/ }
#line 2841 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 37: /* class_member ::= default_def */
      case 79: /*mixin_class_member ::= default_def */ yytestcase(yyruleno==79);
#line 330 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy205; /*X-overwrites-A*/ }
#line 2847 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 39: /* class_member ::= property_def */
      case 81: /*mixin_class_member ::= property_def */ yytestcase(yyruleno==81);
#line 332 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy387; /*X-overwrites-A*/ }
#line 2853 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 40: /* class_member ::= flag_def */
      case 82: /*mixin_class_member ::= flag_def */ yytestcase(yyruleno==82);
#line 333 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy73; /*X-overwrites-A*/ }
#line 2859 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 41: /* class_member ::= staticarray_statement */
      case 61: /*struct_member ::= staticarray_statement */ yytestcase(yyruleno==61);
      case 83: /*mixin_class_member ::= staticarray_statement */ yytestcase(yyruleno==83);
#line 334 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy152; /*X-overwrites-A*/ }
#line 2866 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 42: /* mixin_statement ::= MIXIN IDENTIFIER SEMICOLON */
#line 339 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinStmt,stmt,yymsp[-2].minor.yy0);
	stmt->MixinName = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy523 = stmt;
}
#line 2875 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy523 = yylhsminor.yy523;
        break;
      case 43: /* property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON */
#line 354 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Property,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Body = yymsp[-1].minor.yy35;
	yylhsminor.yy387 = def;
}
#line 2887 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy387 = yylhsminor.yy387;
        break;
      case 44: /* flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON */
#line 362 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagDef,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->RefName = yymsp[-3].minor.yy0.Name();
	def->BitValue = yymsp[-1].minor.yy0.Int;
	yylhsminor.yy73 = def;
}
#line 2901 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-6].minor.yy73 = yylhsminor.yy73;
        break;
      case 46: /* identifier_list ::= states_opt COMMA IDENTIFIER */
      case 88: /*states_opt ::= states_opt COMMA IDENTIFIER */ yytestcase(yyruleno==88);
#line 379 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id);
}
#line 2916 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 47: /* struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon */
#line 387 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy38;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Version = yymsp[-4].minor.yy37.Version;
	def->Flags = yymsp[-4].minor.yy37.Flags;
	yylhsminor.yy262 = def;
}
#line 2931 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yymsp[-6].minor.yy262 = yylhsminor.yy262;
        break;
      case 48: /* struct_def ::= EXTEND STRUCT IDENTIFIER LBRACE opt_struct_body RBRACE opt_semicolon */
{  yy_destructor(yypParser,52,&yymsp[-6].minor);
#line 399 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-5].minor.yy0);
	def->NodeName = yymsp[-4].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy38;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Flags = ZCC_Extension;
	yymsp[-6].minor.yy262 = def;
}
#line 2948 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
}
        break;
      case 49: /* struct_flags ::= */
#line 410 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy37.Flags = 0; yymsp[1].minor.yy37.Version = {0, 0}; }
#line 2956 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 50: /* struct_flags ::= struct_flags UI */
#line 411 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_UIFlag; }
#line 2961 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 51: /* struct_flags ::= struct_flags PLAY */
#line 412 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Play; }
#line 2968 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 52: /* struct_flags ::= struct_flags CLEARSCOPE */
#line 413 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_ClearScope; }
#line 2975 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,72,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 53: /* struct_flags ::= struct_flags NATIVE */
#line 414 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Native; }
#line 2982 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 54: /* struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN */
#line 415 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-4].minor.yy37.Flags | ZCC_Version; yylhsminor.yy37.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2989 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy37 = yylhsminor.yy37;
        break;
      case 57: /* struct_body ::= struct_body struct_member */
#line 423 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy38 = yymsp[-1].minor.yy38; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-1].minor.yy38, yymsp[0].minor.yy38); }
#line 2998 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 62: /* const_def ::= CONST IDENTIFIER EQ expr SEMICOLON */
#line 433 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Value = yymsp[-1].minor.yy138;
	def->Symbol = NULL;
	yylhsminor.yy307 = def;
}
#line 3009 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy307 = yylhsminor.yy307;
        break;
      case 63: /* enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon */
#line 450 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Enum,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->EnumType = (EZCCBuiltinType)yymsp[-4].minor.yy0.Int;
	def->Elements = yymsp[-2].minor.yy307;
	def->Symbol = nullptr;

	// If the first element does not have an explicit value, make it 0.
	if (yymsp[-2].minor.yy307 != NULL)
	{
		ZCC_ConstantDef *node = yymsp[-2].minor.yy307, *prev = node;

		if (node->Value == NULL)
		{
			NEW_INTCONST_NODE(zero, TypeSInt32, 0, yymsp[-2].minor.yy307);
			node->Value = zero;
		}
		for (node = static_cast<ZCC_ConstantDef *>(node->SiblingNext);
			node != yymsp[-2].minor.yy307;
			prev = node, node = static_cast<ZCC_ConstantDef *>(node->SiblingNext))
		{
			assert(node->NodeType == AST_ConstantDef);
			// Leave explicit values alone.
			if (node->Value != NULL)
			{
				continue;
			}
			// Compute implicit values by adding one to the preceding value.
			assert(prev->Value != NULL);
			// If the preceding node is a constant, then we can do this now.
			if (prev->Value->Operation == PEX_ConstValue && prev->Value->Type->isInt())
			{
				NEW_INTCONST_NODE(cval, prev->Value->Type, static_cast<ZCC_ExprConstant *>(prev->Value)->IntVal + 1, node);
				node->Value = cval;
			}
			// Otherwise, create a new addition expression to add 1.
			else
			{
				NEW_INTCONST_NODE(one, TypeSInt32, 1, yymsp[-6].minor.yy0);
				NEW_AST_NODE(ExprID, label, node);
				label->Operation = PEX_ID;
				label->Identifier = prev->NodeName;
				label->Type = NULL;

				BINARY_EXPR(label, one, PEX_Add);
				node->Value = expr2;
			}
		}
		// Add a new terminating node, to indicate that the ConstantDefs for this enum are done.
		NEW_AST_NODE(EnumTerminator,term,yymsp[-1].minor.yy0);
		AppendTreeNodeSibling(yymsp[-2].minor.yy307, term);
	}
	if (yymsp[-2].minor.yy307 != NULL)
	{
		AppendTreeNodeSibling(def, yymsp[-2].minor.yy307);
	}
	yylhsminor.yy245 = def;
}
#line 3074 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yymsp[-6].minor.yy245 = yylhsminor.yy245;
        break;
      case 64: /* enum_type ::= */
#line 509 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = ZCC_IntAuto; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 3081 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 65: /* enum_type ::= COLON int_type */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 510 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; /*yymsp[-1].minor.yy0-overwrites-yymsp[0].minor.yy0*/ }
#line 3087 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 66: /* enum_list ::= error */
#line 512 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy307 = NULL; }
#line 3093 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 67: /* enum_list ::= enum_list COMMA enumerator */
#line 514 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy307 = yymsp[-2].minor.yy307; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy307, yymsp[0].minor.yy307); }
#line 3098 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 68: /* opt_enum_list ::= */
#line 516 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy307 = NULL; }
#line 3104 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 69: /* enumerator ::= IDENTIFIER */
#line 520 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[0].minor.yy0);
	node->NodeName = yymsp[0].minor.yy0.Name();
	node->Value = NULL;
	node->Symbol = NULL;
	yylhsminor.yy307 = node;
}
#line 3115 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy307 = yylhsminor.yy307;
        break;
      case 70: /* enumerator ::= IDENTIFIER EQ expr */
#line 528 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[-2].minor.yy0);
	node->NodeName = yymsp[-2].minor.yy0.Name();
	node->Value = yymsp[0].minor.yy138;
	node->Symbol = NULL;
	yylhsminor.yy307 = node;
}
#line 3127 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy307 = yylhsminor.yy307;
        break;
      case 71: /* mixin_definition ::= mixin_class_definition */
#line 542 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy48 = yymsp[0].minor.yy48; /*X-overwrites-A*/ }
#line 3134 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 72: /* mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE */
#line 549 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinDef,def,yymsp[-5].minor.yy0);
	def->Body = yymsp[-1].minor.yy38;
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->MixinType = ZCC_Mixin_Class;
	def->Symbol = nullptr;
	yylhsminor.yy48 = def;
}
#line 3146 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy48 = yylhsminor.yy48;
        break;
      case 84: /* states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE */
#line 598 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(States,def,yymsp[-5].minor.yy0);
	def->Flags = yymsp[-4].minor.yy35;
	def->Body = yymsp[-1].minor.yy272;
	yylhsminor.yy276 = def;
}
#line 3160 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy276 = yylhsminor.yy276;
        break;
      case 85: /* states_opts ::= */
#line 605 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy35 = nullptr; }
#line 3168 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 86: /* states_opts ::= LPAREN states_opt RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 606 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy35 = yymsp[-1].minor.yy35; /*yymsp[-2].minor.yy35-overwrites-yymsp[-1].minor.yy35*/ }
#line 3174 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 89: /* scanner_mode ::= */
#line 635 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ stat->sc->SetStateMode(true); }
#line 3181 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 90: /* states_body ::= */
#line 637 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy272 = NULL; }
#line 3186 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 91: /* states_body ::= error */
#line 638 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy272 = NULL; }
#line 3191 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 92: /* states_body ::= states_body state_line */
      case 93: /*states_body ::= states_body state_label */ yytestcase(yyruleno==93);
      case 94: /*states_body ::= states_body state_flow */ yytestcase(yyruleno==94);
#line 639 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy272,yymsp[0].minor.yy272); }
#line 3198 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 95: /* state_label ::= NWS COLON */
#line 644 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLabel, label, yymsp[-1].minor.yy0);
	label->Label = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy272 = label;
}
#line 3207 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy272 = yylhsminor.yy272;
        break;
      case 96: /* state_flow_type ::= STOP */
#line 652 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateStop, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3214 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 97: /* state_flow_type ::= WAIT */
#line 653 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateWait, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3220 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 98: /* state_flow_type ::= FAIL */
#line 654 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateFail, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3226 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 99: /* state_flow_type ::= LOOP */
#line 655 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateLoop, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3232 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 100: /* state_flow_type ::= GOTO dottable_id state_goto_offset */
#line 657 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-2].minor.yy0);
	flow->Label = yymsp[-1].minor.yy35;
	flow->Offset = yymsp[0].minor.yy138;
	flow->Qualifier = nullptr;
	yylhsminor.yy272 = flow;
}
#line 3244 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-2].minor.yy272 = yylhsminor.yy272;
        break;
      case 101: /* state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset */
#line 666 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy35;
	flow->Offset = yymsp[0].minor.yy138;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = yymsp[-3].minor.yy0.Name();
	flow->Qualifier =id;
	yylhsminor.yy272 = flow;
}
#line 3259 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy272 = yylhsminor.yy272;
        break;
      case 102: /* state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset */
#line 678 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy35;
	flow->Offset = yymsp[0].minor.yy138;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = NAME_Super;
	flow->Qualifier =id;
	yylhsminor.yy272 = flow;
}
#line 3275 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy272 = yylhsminor.yy272;
        break;
      case 103: /* state_goto_offset ::= */
#line 689 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy138 = NULL; }
#line 3282 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 104: /* state_goto_offset ::= ADD expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 690 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy138 = yymsp[0].minor.yy138; /*yymsp[-1].minor.yy138-overwrites-yymsp[0].minor.yy138*/ }
#line 3288 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 105: /* state_line ::= NWS NWS expr state_opts state_action */
#line 693 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLine, line, yymsp[-4].minor.yy0);
	line->Sprite = stat->Strings.Alloc(FName(yymsp[-4].minor.yy0.Name()).GetChars());
	line->Frames = stat->Strings.Alloc(FName(yymsp[-3].minor.yy0.Name()).GetChars());
	line->Duration = yymsp[-2].minor.yy138;
	line->bBright = yymsp[-1].minor.yy424.Bright;
	line->bFast = yymsp[-1].minor.yy424.Fast;
	line->bSlow = yymsp[-1].minor.yy424.Slow;
	line->bNoDelay = yymsp[-1].minor.yy424.NoDelay;
	line->bCanRaise = yymsp[-1].minor.yy424.CanRaise;
	line->Offset = yymsp[-1].minor.yy424.Offset;
	line->Lights = yymsp[-1].minor.yy424.Lights;
	line->Action = yymsp[0].minor.yy38;
	yylhsminor.yy272 = line;
}
#line 3308 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-4].minor.yy272 = yylhsminor.yy272;
        break;
      case 106: /* state_opts ::= */
#line 709 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ StateOpts opts; opts.Zero(); yymsp[1].minor.yy424 = opts; }
#line 3314 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 107: /* state_opts ::= state_opts BRIGHT */
#line 710 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.Bright = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3319 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,83,&yymsp[0].minor);
        break;
      case 108: /* state_opts ::= state_opts FAST */
#line 711 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.Fast = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3325 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,84,&yymsp[0].minor);
        break;
      case 109: /* state_opts ::= state_opts SLOW */
#line 712 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.Slow = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3331 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,85,&yymsp[0].minor);
        break;
      case 110: /* state_opts ::= state_opts NODELAY */
#line 713 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.NoDelay = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3337 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,86,&yymsp[0].minor);
        break;
      case 111: /* state_opts ::= state_opts CANRAISE */
#line 714 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.CanRaise = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3343 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,87,&yymsp[0].minor);
        break;
      case 112: /* state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN */
#line 715 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-6].minor.yy424.Offset = yymsp[-3].minor.yy138; AppendTreeNodeSibling(yymsp[-3].minor.yy138, yymsp[-1].minor.yy138); yymsp[-6].minor.yy424 = yymsp[-6].minor.yy424; /*X-overwrites-A*/ }
#line 3349 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,88,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 113: /* state_opts ::= state_opts LIGHT LPAREN light_list RPAREN */
#line 716 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-4].minor.yy424 = yymsp[-4].minor.yy424; /*X-overwrites-A*/ yymsp[-4].minor.yy424.Lights = yymsp[-1].minor.yy237; }
#line 3358 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,89,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 114: /* light_list ::= STRCONST */
      case 281: /*string_constant ::= STRCONST */ yytestcase(yyruleno==281);
#line 721 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	yylhsminor.yy237 = strconst;
}
#line 3373 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 115: /* light_list ::= light_list COMMA STRCONST */
#line 730 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	AppendTreeNodeSibling(yymsp[-2].minor.yy237, strconst); 
	yymsp[-2].minor.yy237 = yymsp[-2].minor.yy237; /*X-overwrites-A*/
}
#line 3386 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 116: /* state_action ::= LBRACE statement_list scanner_mode RBRACE */
#line 741 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-3].minor.yy0);
	stmt->Content = yymsp[-2].minor.yy181;
	yylhsminor.yy38 = stmt;
}
#line 3396 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-3].minor.yy38 = yylhsminor.yy38;
        break;
      case 117: /* state_action ::= LBRACE scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 747 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy38 = NULL;
}
#line 3406 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 118: /* state_action ::= LBRACE error scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-3].minor);
#line 750 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-3].minor.yy38 = NULL; }
#line 3414 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 119: /* state_action ::= state_call scanner_mode SEMICOLON */
#line 751 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy38 = yymsp[-2].minor.yy519; /*X-overwrites-A*/ }
#line 3421 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 120: /* state_call ::= */
#line 753 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy519 = NULL; }
#line 3427 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 121: /* state_call ::= IDENTIFIER state_call_params */
#line 755 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-1].minor.yy0);
	NEW_AST_NODE(ExprID, func, yymsp[-1].minor.yy0);

	func->Operation = PEX_ID;
	func->Identifier = yymsp[-1].minor.yy0.Name();
	expr->Operation = PEX_FuncCall;
	expr->Function = func;
	expr->Parameters = yymsp[0].minor.yy28;
	yylhsminor.yy519 = expr;
}
#line 3442 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy519 = yylhsminor.yy519;
        break;
      case 122: /* state_call_params ::= */
#line 767 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy28 = NULL; }
#line 3448 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 123: /* state_call_params ::= LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 768 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy28 = yymsp[-1].minor.yy28; /*yymsp[-2].minor.yy28-overwrites-yymsp[-1].minor.yy28*/ }
#line 3454 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 124: /* default_def ::= DEFAULT LBRACE RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-2].minor);
#line 776 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yymsp[-2].minor.yy205 = stmt;
}
#line 3466 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 125: /* default_def ::= DEFAULT LBRACE default_statement_list RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 782 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy181;
	yymsp[-3].minor.yy205 = stmt;
}
#line 3478 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 126: /* default_def ::= DEFAULT LBRACE error RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 788 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yymsp[-3].minor.yy205 = stmt;
}
#line 3490 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 127: /* default_statement_list ::= default_statement */
      case 307: /*statement_list ::= statement */ yytestcase(yyruleno==307);
#line 795 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[0].minor.yy181 = yymsp[0].minor.yy181; /*X-overwrites-A*/
}
#line 3500 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 128: /* default_statement_list ::= default_statement_list default_statement */
      case 308: /*statement_list ::= statement_list statement */ yytestcase(yyruleno==308);
#line 799 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	SAFE_APPEND(yymsp[-1].minor.yy181,yymsp[0].minor.yy181);
}
#line 3508 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 129: /* default_statement ::= SEMICOLON */
      case 290: /*statement ::= SEMICOLON */ yytestcase(yyruleno==290);
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 804 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = NULL; }
#line 3515 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 130: /* default_statement ::= error SEMICOLON */
      case 296: /*statement ::= error SEMICOLON */ yytestcase(yyruleno==296);
#line 805 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = NULL; }
#line 3522 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 131: /* default_statement ::= property_statement */
#line 807 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy213; /*X-overwrites-A*/ }
#line 3528 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 132: /* default_statement ::= flag_statement */
#line 808 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy380; /*X-overwrites-A*/ }
#line 3533 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 133: /* flag_statement ::= ADD dottable_id */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 813 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy35);
	type->set = true;
	type->name = yymsp[0].minor.yy35;
	yymsp[-1].minor.yy380 = type;
}
#line 3544 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 134: /* flag_statement ::= SUB dottable_id */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 820 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy35);
	type->set = false;
	type->name = yymsp[0].minor.yy35;
	yymsp[-1].minor.yy380 = type;
}
#line 3556 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 135: /* property_statement ::= dottable_id expr_list SEMICOLON */
#line 830 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-2].minor.yy35);
	stmt->Prop = yymsp[-2].minor.yy35;
	stmt->Values = yymsp[-1].minor.yy138;
	yylhsminor.yy213 = stmt;
}
#line 3567 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy213 = yylhsminor.yy213;
        break;
      case 136: /* property_statement ::= dottable_id SEMICOLON */
#line 838 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-1].minor.yy35);
	stmt->Prop = yymsp[-1].minor.yy35;
	stmt->Values = nullptr;
	yylhsminor.yy213 = stmt;
}
#line 3579 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy213 = yylhsminor.yy213;
        break;
      case 137: /* int_type ::= SBYTE */
#line 850 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3586 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 138: /* int_type ::= BYTE */
#line 851 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3592 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 139: /* int_type ::= SHORT */
#line 852 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3598 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 140: /* int_type ::= USHORT */
#line 853 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3604 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 141: /* int_type ::= INT */
#line 854 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3610 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 142: /* int_type ::= UINT */
#line 855 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3616 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 143: /* type_name1 ::= BOOL */
#line 857 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Bool; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3622 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 144: /* type_name1 ::= FLOAT */
#line 859 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FloatAuto; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3628 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 145: /* type_name1 ::= DOUBLE */
#line 860 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Float64; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3634 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 146: /* type_name1 ::= VECTOR2 */
#line 862 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector2; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3640 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 147: /* type_name1 ::= VECTOR3 */
#line 863 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector3; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3646 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 148: /* type_name1 ::= NAME */
#line 864 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Name; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3652 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 149: /* type_name1 ::= SOUND */
#line 865 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Sound; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3658 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 150: /* type_name1 ::= STATE */
#line 866 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_State; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3664 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 151: /* type_name1 ::= COLOR */
#line 867 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Color; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3670 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 152: /* type_name1 ::= LET */
#line 868 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Let; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3676 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 153: /* type_name ::= type_name1 */
#line 871 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	type->Type = (EZCCBuiltinType)yymsp[0].minor.yy0.Int;
	type->UserType = NULL;
	type->isconst = false;
	yylhsminor.yy42 = type;
}
#line 3688 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy42 = yylhsminor.yy42;
        break;
      case 154: /* type_name ::= IDENTIFIER */
#line 879 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy42 = type;
}
#line 3702 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy42 = yylhsminor.yy42;
        break;
      case 155: /* type_name ::= ATSIGN IDENTIFIER */
{  yy_destructor(yypParser,105,&yymsp[-1].minor);
#line 890 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-1].minor.yy42 = type;
}
#line 3717 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 156: /* type_name ::= READONLY LT IDENTIFIER GT */
{  yy_destructor(yypParser,106,&yymsp[-3].minor);
#line 901 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-3].minor.yy42 = type;
}
#line 3732 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 157: /* type_name ::= READONLY LT ATSIGN IDENTIFIER GT */
{  yy_destructor(yypParser,106,&yymsp[-4].minor);
#line 912 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-4].minor.yy42 = type;
}
#line 3749 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,105,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 158: /* type_name ::= DOT dottable_id */
{  yy_destructor(yypParser,44,&yymsp[-1].minor);
#line 923 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy35);
	type->Type = ZCC_UserType;
	type->UserType = yymsp[0].minor.yy35;
	type->isconst = false;
	yymsp[-1].minor.yy42 = type;
}
#line 3765 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 159: /* aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT */
#line 947 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MapType,map,yymsp[-5].minor.yy0);
	map->KeyType = yymsp[-3].minor.yy6;
	map->ValueType = yymsp[-1].minor.yy6;
	yylhsminor.yy6 = map;
}
#line 3776 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-5].minor.yy6 = yylhsminor.yy6;
        break;
      case 160: /* aggregate_type ::= ARRAY LT type_or_array GT */
#line 955 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(DynArrayType,arr,yymsp[-3].minor.yy0);
	arr->ElementType = yymsp[-1].minor.yy6;
	yylhsminor.yy6 = arr;
}
#line 3789 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-3].minor.yy6 = yylhsminor.yy6;
        break;
      case 161: /* aggregate_type ::= CLASS class_restrictor */
#line 962 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[-1].minor.yy0);
	cls->Restriction = yymsp[0].minor.yy35;
	yylhsminor.yy6 = cls;
}
#line 3801 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy6 = yylhsminor.yy6;
        break;
      case 163: /* class_restrictor ::= LT dottable_id GT */
{  yy_destructor(yypParser,20,&yymsp[-2].minor);
#line 968 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy35 = yymsp[-1].minor.yy35; /*yymsp[-2].minor.yy35-overwrites-yymsp[-1].minor.yy35*/ }
#line 3808 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 164: /* type ::= type_name */
#line 970 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy6 = yymsp[0].minor.yy42; /*X-overwrites-A*/ yymsp[0].minor.yy6->ArraySize = NULL; }
#line 3815 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 165: /* type ::= aggregate_type */
#line 971 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy6 = yymsp[0].minor.yy6; /*X-overwrites-A*/ yymsp[0].minor.yy6->ArraySize = NULL; }
#line 3820 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 166: /* type_or_array ::= type array_size */
#line 974 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy6 = yymsp[-1].minor.yy6; /*X-overwrites-A*/ yymsp[-1].minor.yy6->ArraySize = yymsp[0].minor.yy138; }
#line 3825 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 167: /* type_list ::= type_list COMMA type_or_array */
#line 977 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy6 = yymsp[-2].minor.yy6; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy6, yymsp[0].minor.yy6); }
#line 3830 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 168: /* type_list_or_void ::= VOID */
{  yy_destructor(yypParser,110,&yymsp[0].minor);
#line 979 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy6 = NULL; }
#line 3837 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 169: /* array_size_expr ::= LBRACKET opt_expr RBRACKET */
#line 983 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy138 == NULL)
	{
		NEW_AST_NODE(Expression,nil,yymsp[-2].minor.yy0.SourceLoc);
		nil->Operation = PEX_Nil;
		nil->Type = NULL;
		yylhsminor.yy138 = nil;
	}
	else
	{
		yylhsminor.yy138 = yymsp[-1].minor.yy138;
	}
}
#line 3855 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,115,&yymsp[0].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 170: /* array_size ::= array_size array_size_expr */
#line 998 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-1].minor.yy138, yymsp[0].minor.yy138);
	yymsp[-1].minor.yy138 = yymsp[-1].minor.yy138; /*X-overwrites-A*/
}
#line 3865 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 171: /* declarator ::= decl_flags type_list_or_void variables_or_function */
#line 1007 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[0].minor.yy34.FuncName == NAME_None && yymsp[0].minor.yy34.VarNames == NULL)
	{ // An error. yymsp[-2].minor.yy139 message was already printed.
		yylhsminor.yy243 = NULL;
	}
	else if (yymsp[0].minor.yy34.FuncName != NAME_None)
	{ // yymsp[-2].minor.yy139 function
		NEW_AST_NODE(FuncDeclarator, decl, yymsp[-2].minor.yy139 == nullptr? yymsp[0].minor.yy34.SourceLoc : yymsp[-2].minor.yy139->SourceLoc);
		decl->Type = yymsp[-1].minor.yy6;
		decl->Params = yymsp[0].minor.yy34.FuncParams;
		decl->Name = yymsp[0].minor.yy34.FuncName;
		decl->UseFlags = yymsp[-2].minor.yy139 == nullptr? nullptr : yymsp[-2].minor.yy139->Id;
		decl->Flags = (yymsp[-2].minor.yy139 == nullptr? 0 : yymsp[-2].minor.yy139->Flags) | yymsp[0].minor.yy34.FuncFlags;
		decl->DeprecationMessage = yymsp[-2].minor.yy139 == nullptr ? nullptr : yymsp[-2].minor.yy139->DeprecationMessage;
		if (yymsp[-2].minor.yy139 == nullptr) decl->Version = {0,0,0};
		else decl->Version = yymsp[-2].minor.yy139->Version;

		decl->Body = yymsp[0].minor.yy34.FuncBody;
		yylhsminor.yy243 = decl;
	}
	else if (yymsp[-1].minor.yy6 != NULL && yymsp[-1].minor.yy6->SiblingNext == yymsp[-1].minor.yy6)
	{ // yymsp[-2].minor.yy139 variable
		NEW_AST_NODE(VarDeclarator, decl, yymsp[-2].minor.yy139 == nullptr? yymsp[-1].minor.yy6->SourceLoc : yymsp[-2].minor.yy139->SourceLoc);
		decl->Type = yymsp[-1].minor.yy6;
		decl->Names = yymsp[0].minor.yy34.VarNames;
		if (yymsp[-2].minor.yy139 == nullptr)
		{
			decl->Flags = 0;
			decl->Version = {0,0,0};
			decl->DeprecationMessage = nullptr;
		}
		else
		{
			decl->Flags = yymsp[-2].minor.yy139->Flags;
			decl->Version = yymsp[-2].minor.yy139->Version;
			decl->DeprecationMessage = yymsp[-2].minor.yy139->DeprecationMessage;
		}
		yylhsminor.yy243 = decl;
	}
	else
	{ // An invalid
		if (yymsp[-1].minor.yy6 == NULL)
		{
			stat->sc->ScriptMessage("Variables may not be of type void.\n");
		}
		else
		{
			stat->sc->ScriptMessage("Variables may be of only one type.\n");
		}
		yylhsminor.yy243 = NULL;
	}
}
#line 3921 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-2].minor.yy243 = yylhsminor.yy243;
        break;
      case 172: /* variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body */
#line 1062 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun fun;

	fun.VarNames = NULL;
	fun.FuncParams = yymsp[-3].minor.yy433;
	fun.FuncFlags = yymsp[-1].minor.yy0.Int;
	fun.FuncName = yymsp[-5].minor.yy0.Name();
	fun.FuncBody = yymsp[0].minor.yy261;
	fun.SourceLoc = yymsp[-5].minor.yy0.SourceLoc;
	yylhsminor.yy34 = fun;
}
#line 3937 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-2].minor);
  yymsp[-5].minor.yy34 = yylhsminor.yy34;
        break;
      case 173: /* variables_or_function ::= variable_list SEMICOLON */
#line 1074 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun var;

	var.VarNames = yymsp[-1].minor.yy273;
	var.FuncParams = NULL;
	var.FuncFlags = 0;
	var.FuncName = NAME_None;
	var.FuncBody = NULL;
	var.SourceLoc = yymsp[-1].minor.yy273->SourceLoc;
	yylhsminor.yy34 = var;
}
#line 3955 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy34 = yylhsminor.yy34;
        break;
      case 174: /* variables_or_function ::= error SEMICOLON */
#line 1086 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun bad;
	bad.VarNames = NULL;
	bad.FuncParams = NULL;
	bad.FuncFlags = 0;
	bad.FuncName = NAME_None;
	bad.FuncBody = NULL;
	bad.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
	yymsp[-1].minor.yy34 = bad;
}
#line 3971 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 175: /* variable_name ::= IDENTIFIER */
#line 1103 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	yylhsminor.yy273 = var;
}
#line 3981 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 176: /* variable_name ::= IDENTIFIER array_size */
#line 1110 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy138;
	yylhsminor.yy273 = var;
}
#line 3992 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy273 = yylhsminor.yy273;
        break;
      case 177: /* variable_list ::= variable_list COMMA variable_name */
#line 1119 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy273, yymsp[0].minor.yy273);
	yymsp[-2].minor.yy273 = yymsp[-2].minor.yy273; /*X-overwrites-A*/
}
#line 4001 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 178: /* decl_flags ::= */
#line 1125 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy139 = NULL; }
#line 4007 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 179: /* decl_flags ::= decl_flags decl_flag */
#line 1127 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[0].minor.yy0);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Flags = yymsp[0].minor.yy0.Int;
		yylhsminor.yy139->Version = { 0, 0 };
		yylhsminor.yy139->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy139 = yymsp[-1].minor.yy139;
		yylhsminor.yy139->Flags |= yymsp[0].minor.yy0.Int;
	}
}
#line 4027 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy139 = yylhsminor.yy139;
        break;
      case 180: /* decl_flags ::= decl_flags ACTION states_opts */
#line 1146 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-2].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-1].minor.yy0.SourceLoc);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Flags = ZCC_Action;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Version = { 0, 0 };
		yylhsminor.yy139->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy139 = yymsp[-2].minor.yy139;
		yylhsminor.yy139->Flags |= ZCC_Action;
	}
	yylhsminor.yy139->Id = yymsp[0].minor.yy35;
}
#line 4049 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-2].minor.yy139 = yylhsminor.yy139;
        break;
      case 181: /* opt_deprecation_message ::= */
#line 1164 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.String = nullptr; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4055 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 182: /* opt_deprecation_message ::= COMMA STRCONST */
{  yy_destructor(yypParser,50,&yymsp[-1].minor);
#line 1165 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4061 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 183: /* decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN */
#line 1168 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-5].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-4].minor.yy0.SourceLoc);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Flags = ZCC_Deprecated;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy139 = yymsp[-5].minor.yy139;
		yylhsminor.yy139->Flags |= ZCC_Deprecated;
	}
	yylhsminor.yy139->Version = yymsp[-2].minor.yy0.String->GetChars();
	yylhsminor.yy139->DeprecationMessage = yymsp[-1].minor.yy0.String;
}
#line 4083 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy139 = yylhsminor.yy139;
        break;
      case 184: /* decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN */
#line 1187 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Flags = ZCC_Version;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Version = { 0, 0 };
		yylhsminor.yy139->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy139 = yymsp[-4].minor.yy139;
		yylhsminor.yy139->Flags |= ZCC_Version;
	}
	yylhsminor.yy139->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 4107 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy139 = yylhsminor.yy139;
        break;
      case 185: /* decl_flag ::= NATIVE */
#line 1205 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Native; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4115 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 186: /* decl_flag ::= STATIC */
#line 1206 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Static; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4121 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 187: /* decl_flag ::= PRIVATE */
#line 1207 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Private; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4127 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 188: /* decl_flag ::= PROTECTED */
#line 1208 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Protected; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4133 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 189: /* decl_flag ::= LATENT */
#line 1209 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Latent; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4139 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 190: /* decl_flag ::= FINAL */
#line 1210 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Final; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4145 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 191: /* decl_flag ::= META */
#line 1211 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Meta; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4151 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 192: /* decl_flag ::= TRANSIENT */
#line 1212 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Transient; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4157 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 193: /* decl_flag ::= READONLY */
#line 1213 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ReadOnly; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4163 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 194: /* decl_flag ::= INTERNAL */
#line 1214 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Internal; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4169 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 195: /* decl_flag ::= VIRTUAL */
#line 1215 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Virtual; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4175 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 196: /* decl_flag ::= OVERRIDE */
#line 1216 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Override; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4181 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 197: /* decl_flag ::= ABSTRACT */
#line 1217 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Abstract; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4187 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 198: /* decl_flag ::= VARARG */
#line 1218 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VarArg; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4193 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 199: /* decl_flag ::= UI */
#line 1219 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UIFlag; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4199 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 200: /* decl_flag ::= PLAY */
#line 1220 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Play; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4205 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 201: /* decl_flag ::= CLEARSCOPE */
#line 1221 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ClearScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4211 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 202: /* decl_flag ::= VIRTUALSCOPE */
#line 1222 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VirtualScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4217 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 203: /* func_const ::= */
#line 1224 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4223 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 204: /* func_const ::= CONST */
#line 1225 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FuncConst; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4228 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 205: /* opt_func_body ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 1227 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy261 = NULL; }
#line 4235 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 206: /* func_params ::= */
#line 1234 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy433 = NULL; }
#line 4241 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 207: /* func_params ::= VOID */
{  yy_destructor(yypParser,110,&yymsp[0].minor);
#line 1235 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy433 = NULL; }
#line 4247 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 208: /* func_params ::= func_param_list COMMA ELLIPSIS */
#line 1239 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,stat->sc->GetMessageLine());
	parm->Type = nullptr;
	parm->Name = NAME_None;
	parm->Flags = 0;
	parm->Default = nullptr;
	yymsp[-2].minor.yy433 = yymsp[-2].minor.yy433; /*X-overwrites-A*/ 
	AppendTreeNodeSibling(yymsp[-2].minor.yy433, parm);
}
#line 4261 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yy_destructor(yypParser,130,&yymsp[0].minor);
        break;
      case 209: /* func_param_list ::= func_param_list COMMA func_param */
#line 1250 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy433 = yymsp[-2].minor.yy433; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy433, yymsp[0].minor.yy433); }
#line 4268 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 210: /* func_param ::= func_param_flags type IDENTIFIER */
#line 1253 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy6->SourceLoc);
	parm->Type = yymsp[-1].minor.yy6;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-2].minor.yy0.Int;
	parm->Default = nullptr;
	yylhsminor.yy433 = parm;
}
#line 4281 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-2].minor.yy433 = yylhsminor.yy433;
        break;
      case 211: /* func_param ::= func_param_flags type IDENTIFIER EQ expr */
#line 1263 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-4].minor.yy0.SourceLoc ? yymsp[-4].minor.yy0.SourceLoc : yymsp[-3].minor.yy6->SourceLoc);
	parm->Type = yymsp[-3].minor.yy6;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-4].minor.yy0.Int;
	parm->Default = yymsp[0].minor.yy138;
	yylhsminor.yy433 = parm;
}
#line 4294 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-4].minor.yy433 = yylhsminor.yy433;
        break;
      case 212: /* func_param_flags ::= */
#line 1272 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = 0; }
#line 4301 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 213: /* func_param_flags ::= func_param_flags IN */
#line 1273 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_In; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4306 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 214: /* func_param_flags ::= func_param_flags OUT */
#line 1274 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Out; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4312 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 215: /* func_param_flags ::= func_param_flags OPTIONAL */
#line 1275 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Optional; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4318 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 216: /* primary ::= IDENTIFIER */
#line 1291 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprID, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_ID;
	expr->Identifier = yymsp[0].minor.yy0.Name();
	expr->Type = NULL;
	yylhsminor.yy138 = expr;
}
#line 4330 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy138 = yylhsminor.yy138;
        break;
      case 217: /* primary ::= SUPER */
#line 1299 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Expression, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_Super;
	expr->Type = NULL;
	yylhsminor.yy138 = expr;
}
#line 4341 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy138 = yylhsminor.yy138;
        break;
      case 218: /* primary ::= constant */
#line 1305 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy138 = yymsp[0].minor.yy237; /*X-overwrites-A*/ }
#line 4347 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 219: /* primary ::= LPAREN expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1307 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-5].minor.yy138);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector3;
	expr->X = yymsp[-5].minor.yy138;
	expr->Y = yymsp[-3].minor.yy138;
	expr->Z = yymsp[-1].minor.yy138;
	yymsp[-6].minor.yy138 = expr;
}
#line 4361 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 220: /* primary ::= LPAREN expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-4].minor);
#line 1317 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-3].minor.yy138);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector2;
	expr->X = yymsp[-3].minor.yy138;
	expr->Y = yymsp[-1].minor.yy138;
	expr->Z = nullptr;
	yymsp[-4].minor.yy138 = expr;
}
#line 4379 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 221: /* primary ::= LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1327 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy138 = yymsp[-1].minor.yy138; /*yymsp[-2].minor.yy138-overwrites-yymsp[-1].minor.yy138*/
}
#line 4390 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 222: /* primary ::= primary LPAREN func_expr_list RPAREN */
#line 1332 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-3].minor.yy138);
	expr->Operation = PEX_FuncCall;
	expr->Type = NULL;
	expr->Function = yymsp[-3].minor.yy138;
	expr->Parameters = yymsp[-1].minor.yy28;
	yylhsminor.yy138 = expr;
}
#line 4404 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-3].minor.yy138 = yylhsminor.yy138;
        break;
      case 223: /* primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1341 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassCast, expr, yymsp[-5].minor.yy0);
	expr->Operation = PEX_ClassCast;
	expr->ClassName = ENamedName(yymsp[-5].minor.yy0.Int);
	expr->Parameters = yymsp[-1].minor.yy28;
	yymsp[-8].minor.yy138 = expr;
}
#line 4419 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-7].minor);
  yy_destructor(yypParser,20,&yymsp[-6].minor);
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 224: /* primary ::= primary LBRACKET expr RBRACKET */
#line 1349 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprBinary, expr, yymsp[-1].minor.yy138);
	expr->Operation = PEX_ArrayAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-3].minor.yy138;
	expr->Right = yymsp[-1].minor.yy138;
	yylhsminor.yy138 = expr;
}
#line 4438 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-2].minor);
  yy_destructor(yypParser,115,&yymsp[0].minor);
  yymsp[-3].minor.yy138 = yylhsminor.yy138;
        break;
      case 225: /* primary ::= primary DOT IDENTIFIER */
#line 1358 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprMemberAccess, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_MemberAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-2].minor.yy138;
	expr->Right = ENamedName(yymsp[0].minor.yy0.Int);
	yylhsminor.yy138 = expr;
}
#line 4453 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 226: /* primary ::= primary ADDADD */
#line 1367 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy138,PEX_PostInc);
	yylhsminor.yy138 = expr1;
}
#line 4463 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,42,&yymsp[0].minor);
  yymsp[-1].minor.yy138 = yylhsminor.yy138;
        break;
      case 227: /* primary ::= primary SUBSUB */
#line 1372 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy138,PEX_PostDec);
	yylhsminor.yy138 = expr1;
}
#line 4473 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,43,&yymsp[0].minor);
  yymsp[-1].minor.yy138 = yylhsminor.yy138;
        break;
      case 228: /* unary_expr ::= SUB unary_expr */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 1388 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy138);
	if (yymsp[0].minor.yy138->Operation == PEX_ConstValue && (con->Type->isInt() || con->Type->isFloat()))
	{ // For constants, manipulate the child node directly, and don't create a new node.
		if (con->Type->isInt())
		{
			con->IntVal = -con->IntVal;
		}
		else
		{
			con->DoubleVal = -con->DoubleVal;
		}
		yymsp[-1].minor.yy138 = yymsp[0].minor.yy138;
	}
	else
	{ // For everything else, create a new node and do the negation later.
		UNARY_EXPR(yymsp[0].minor.yy138,PEX_Negate);
		yymsp[-1].minor.yy138 = expr1;
	}
}
#line 4500 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 229: /* unary_expr ::= ADD unary_expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 1409 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	// Even though this is really a no-op, we still need to make a node for
	// it so we can type check that it is being applied to something numeric.
	// But we can do that right now for constant numerals.
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy138);
	if (yymsp[0].minor.yy138->Operation != PEX_ConstValue || (!con->Type->isInt() && !con->Type->isFloat()))
	{
		UNARY_EXPR(yymsp[0].minor.yy138,PEX_AntiNegate);
		yymsp[-1].minor.yy138 = expr1;
	}
	else
	{
		yymsp[-1].minor.yy138 = yymsp[0].minor.yy138;
	}
}
#line 4521 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 230: /* unary_expr ::= SUBSUB unary_expr */
{  yy_destructor(yypParser,43,&yymsp[-1].minor);
#line 1425 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_PreDec);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4531 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 231: /* unary_expr ::= ADDADD unary_expr */
{  yy_destructor(yypParser,42,&yymsp[-1].minor);
#line 1430 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_PreInc);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4541 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 232: /* unary_expr ::= TILDE unary_expr */
{  yy_destructor(yypParser,134,&yymsp[-1].minor);
#line 1435 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_BitNot);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4551 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 233: /* unary_expr ::= BANG unary_expr */
{  yy_destructor(yypParser,135,&yymsp[-1].minor);
#line 1440 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_BoolNot);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4561 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 234: /* unary_expr ::= SIZEOF unary_expr */
{  yy_destructor(yypParser,136,&yymsp[-1].minor);
#line 1445 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_SizeOf);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4571 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 235: /* unary_expr ::= ALIGNOF unary_expr */
{  yy_destructor(yypParser,137,&yymsp[-1].minor);
#line 1450 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_AlignOf);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4581 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 236: /* expr ::= expr ADD expr */
#line 1463 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Add);
	yylhsminor.yy138 = expr2;
}
#line 4590 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,34,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 237: /* expr ::= expr SUB expr */
#line 1468 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Sub);
	yylhsminor.yy138 = expr2;
}
#line 4600 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,33,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 238: /* expr ::= expr MUL expr */
#line 1473 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Mul);
	yylhsminor.yy138 = expr2;
}
#line 4610 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,35,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 239: /* expr ::= expr DIV expr */
#line 1478 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Div);
	yylhsminor.yy138 = expr2;
}
#line 4620 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 240: /* expr ::= expr MOD expr */
#line 1483 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Mod);
	yylhsminor.yy138 = expr2;
}
#line 4630 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,37,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 241: /* expr ::= expr POW expr */
#line 1488 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Pow);
	yylhsminor.yy138 = expr2;
}
#line 4640 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,40,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 242: /* expr ::= expr CROSSPROD expr */
#line 1493 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_CrossProduct);
	yylhsminor.yy138 = expr2;
}
#line 4650 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 243: /* expr ::= expr DOTPROD expr */
#line 1498 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_DotProduct);
	yylhsminor.yy138 = expr2;
}
#line 4660 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,39,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 244: /* expr ::= expr LSH expr */
#line 1503 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LeftShift);
	yylhsminor.yy138 = expr2;
}
#line 4670 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,30,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 245: /* expr ::= expr RSH expr */
#line 1508 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_RightShift);
	yylhsminor.yy138 = expr2;
}
#line 4680 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 246: /* expr ::= expr URSH expr */
#line 1513 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_URightShift);
	yylhsminor.yy138 = expr2;
}
#line 4690 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,32,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 247: /* expr ::= expr DOTDOT expr */
#line 1518 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Concat);
	yylhsminor.yy138 = expr2;
}
#line 4700 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,26,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 248: /* expr ::= expr LT expr */
#line 1524 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LT);
	yylhsminor.yy138 = expr2;
}
#line 4710 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 249: /* expr ::= expr GT expr */
#line 1529 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_GT);
	yylhsminor.yy138 = expr2;
}
#line 4720 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 250: /* expr ::= expr LTEQ expr */
#line 1534 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LTEQ);
	yylhsminor.yy138 = expr2;
}
#line 4730 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,22,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 251: /* expr ::= expr GTEQ expr */
#line 1539 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_GTEQ);
	yylhsminor.yy138 = expr2;
}
#line 4740 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,23,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 252: /* expr ::= expr LTGTEQ expr */
#line 1544 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LTGTEQ);
	yylhsminor.yy138 = expr2;
}
#line 4750 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,24,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 253: /* expr ::= expr IS expr */
#line 1549 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Is);
	yylhsminor.yy138 = expr2;
}
#line 4760 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,25,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 254: /* expr ::= expr EQEQ expr */
#line 1555 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_EQEQ);
	yylhsminor.yy138 = expr2;
}
#line 4770 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,17,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 255: /* expr ::= expr NEQ expr */
#line 1560 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_NEQ);
	yylhsminor.yy138 = expr2;
}
#line 4780 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,18,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 256: /* expr ::= expr APPROXEQ expr */
#line 1565 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_APREQ);
	yylhsminor.yy138 = expr2;
}
#line 4790 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,19,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 257: /* expr ::= expr AND expr */
#line 1571 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BitAnd);
	yylhsminor.yy138 = expr2;
}
#line 4800 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 258: /* expr ::= expr XOR expr */
#line 1576 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BitXor);
	yylhsminor.yy138 = expr2;
}
#line 4810 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,28,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 259: /* expr ::= expr OR expr */
#line 1581 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BitOr);
	yylhsminor.yy138 = expr2;
}
#line 4820 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,27,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 260: /* expr ::= expr ANDAND expr */
#line 1586 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BoolAnd);
	yylhsminor.yy138 = expr2;
}
#line 4830 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,16,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 261: /* expr ::= expr OROR expr */
#line 1591 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BoolOr);
	yylhsminor.yy138 = expr2;
}
#line 4840 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,15,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 262: /* expr ::= expr EQ expr */
#line 1596 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Assign);
	yylhsminor.yy138 = expr2;
}
#line 4850 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 263: /* expr ::= expr ADDEQ expr */
#line 1601 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_AddAssign);
	yylhsminor.yy138 = expr2;
}
#line 4860 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 264: /* expr ::= expr SUBEQ expr */
#line 1606 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_SubAssign);
	yylhsminor.yy138 = expr2;
}
#line 4870 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,6,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 265: /* expr ::= expr MULEQ expr */
#line 1611 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_MulAssign);
	yylhsminor.yy138 = expr2;
}
#line 4880 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,2,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 266: /* expr ::= expr DIVEQ expr */
#line 1616 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_DivAssign);
	yylhsminor.yy138 = expr2;
}
#line 4890 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,3,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 267: /* expr ::= expr MODEQ expr */
#line 1621 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_ModAssign);
	yylhsminor.yy138 = expr2;
}
#line 4900 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,4,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 268: /* expr ::= expr LSHEQ expr */
#line 1626 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LshAssign);
	yylhsminor.yy138 = expr2;
}
#line 4910 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,7,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 269: /* expr ::= expr RSHEQ expr */
#line 1631 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_RshAssign);
	yylhsminor.yy138 = expr2;
}
#line 4920 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,8,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 270: /* expr ::= expr URSHEQ expr */
#line 1636 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_URshAssign);
	yylhsminor.yy138 = expr2;
}
#line 4930 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,12,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 271: /* expr ::= expr ANDEQ expr */
#line 1641 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_AndAssign);
	yylhsminor.yy138 = expr2;
}
#line 4940 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,9,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 272: /* expr ::= expr OREQ expr */
#line 1646 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_OrAssign);
	yylhsminor.yy138 = expr2;
}
#line 4950 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,10,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 273: /* expr ::= expr XOREQ expr */
#line 1651 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_XorAssign);
	yylhsminor.yy138 = expr2;
}
#line 4960 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,11,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 274: /* expr ::= expr SCOPE expr */
#line 1658 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Scope);
	yylhsminor.yy138 = expr2;
}
#line 4970 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 275: /* expr ::= expr QUESTION expr COLON expr */
#line 1666 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprTrinary, expr, yymsp[-4].minor.yy138);
	expr->Operation = PEX_Trinary;
	expr->Type = NULL;
	expr->Test = yymsp[-4].minor.yy138;
	expr->Left = yymsp[-2].minor.yy138;
	expr->Right = yymsp[0].minor.yy138;
	yylhsminor.yy138 = expr;
}
#line 4985 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,13,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-4].minor.yy138 = yylhsminor.yy138;
        break;
      case 276: /* expr_list ::= expr_list COMMA expr */
#line 1682 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy138 = yymsp[-2].minor.yy138;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy138, yymsp[0].minor.yy138);
}
#line 4996 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 277: /* func_expr_list ::= func_expr_list COMMA func_expr_item */
#line 1698 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	// Omitted parameters still need to appear as nodes in the list.
	if (yymsp[-2].minor.yy28 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_a,yymsp[-1].minor.yy0);
		nil_a->Value = NULL;
		nil_a->Label = NAME_None;
		yymsp[-2].minor.yy28 = nil_a;
	}
	if (yymsp[0].minor.yy28 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_b,yymsp[-1].minor.yy0);
		nil_b->Value = NULL;
		nil_b->Label = NAME_None;
		yymsp[0].minor.yy28 = nil_b;
	}
	yymsp[-2].minor.yy28 = yymsp[-2].minor.yy28;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy28, yymsp[0].minor.yy28);
}
#line 5020 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 278: /* func_expr_item ::= */
#line 1719 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[1].minor.yy28 = NULL;
}
#line 5027 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 279: /* named_expr ::= IDENTIFIER COLON expr */
#line 1725 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[-2].minor.yy0);
	parm->Value = yymsp[0].minor.yy138;
	parm->Label = ENamedName(yymsp[-2].minor.yy0.Int);
	yylhsminor.yy28 = parm;
}
#line 5037 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-2].minor.yy28 = yylhsminor.yy28;
        break;
      case 280: /* named_expr ::= expr */
#line 1732 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[0].minor.yy138);
	parm->Value = yymsp[0].minor.yy138;
	parm->Label = NAME_None;
	yylhsminor.yy28 = parm;
}
#line 5049 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy28 = yylhsminor.yy28;
        break;
      case 282: /* string_constant ::= string_constant STRCONST */
#line 1753 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[-1].minor.yy237);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = stat->Strings.Alloc(*(yymsp[-1].minor.yy237->StringVal) + *(yymsp[0].minor.yy0.String));
	yylhsminor.yy237 = strconst;
}
#line 5061 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy237 = yylhsminor.yy237;
        break;
      case 283: /* constant ::= INTCONST */
#line 1763 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeSInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy237 = intconst;
}
#line 5070 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 284: /* constant ::= UINTCONST */
#line 1768 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeUInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy237 = intconst;
}
#line 5079 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 285: /* constant ::= FLOATCONST */
#line 1773 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeFloat64;
	floatconst->DoubleVal = yymsp[0].minor.yy0.Float;
	yylhsminor.yy237 = floatconst;
}
#line 5091 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 286: /* constant ::= NAMECONST */
#line 1781 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeName;
	floatconst->IntVal = yymsp[0].minor.yy0.Int;
	yylhsminor.yy237 = floatconst;
}
#line 5103 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 287: /* constant ::= FALSE */
#line 1789 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, false, yymsp[0].minor.yy0);
	yylhsminor.yy237 = boolconst;
}
#line 5112 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 288: /* constant ::= TRUE */
#line 1794 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, true, yymsp[0].minor.yy0);
	yylhsminor.yy237 = boolconst;
}
#line 5121 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 289: /* constant ::= NULLPTR */
#line 1799 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, nullptrconst, yymsp[0].minor.yy0);
	nullptrconst->Operation = PEX_ConstValue;
	nullptrconst->Type = TypeNullPtr;
	nullptrconst->StringVal = nullptr;
	yylhsminor.yy237 = nullptrconst;
}
#line 5133 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 291: /* statement ::= labeled_statement */
#line 1813 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy164; /*X-overwrites-A*/ }
#line 5139 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 292: /* statement ::= compound_statement */
#line 1814 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy261; /*X-overwrites-A*/ }
#line 5144 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 293: /* statement ::= expression_statement SEMICOLON */
#line 1815 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = yymsp[-1].minor.yy420; /*X-overwrites-A*/ }
#line 5149 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 294: /* statement ::= assign_statement SEMICOLON */
#line 1819 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = yymsp[-1].minor.yy453; /*X-overwrites-A*/ }
#line 5155 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 295: /* statement ::= local_var SEMICOLON */
#line 1820 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = yymsp[-1].minor.yy388; /*X-overwrites-A*/ }
#line 5161 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 297: /* statement ::= staticarray_statement */
#line 1822 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy152; /*X-overwrites-A*/ }
#line 5167 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 298: /* staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,144,&yymsp[-9].minor);
#line 1829 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy6);
	stmt->Type = yymsp[-8].minor.yy6;
	stmt->Id = ENamedName(yymsp[-7].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy138;
	yymsp[-9].minor.yy152 = stmt;
}
#line 5179 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-6].minor);
  yy_destructor(yypParser,115,&yymsp[-5].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 299: /* staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,144,&yymsp[-9].minor);
#line 1838 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy6);
	stmt->Type = yymsp[-8].minor.yy6;
	stmt->Id = ENamedName(yymsp[-5].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy138;
	yymsp[-9].minor.yy152 = stmt;
}
#line 5198 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-7].minor);
  yy_destructor(yypParser,115,&yymsp[-6].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 300: /* jump_statement ::= CONTINUE SEMICOLON */
#line 1851 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ContinueStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy181 = stmt;
}
#line 5213 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy181 = yylhsminor.yy181;
        break;
      case 301: /* jump_statement ::= BREAK SEMICOLON */
#line 1856 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BreakStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy181 = stmt;
}
#line 5223 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy181 = yylhsminor.yy181;
        break;
      case 302: /* jump_statement ::= RETURN SEMICOLON */
#line 1861 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-1].minor.yy0);
	stmt->Values = NULL;
	yylhsminor.yy181 = stmt;
}
#line 5234 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy181 = yylhsminor.yy181;
        break;
      case 303: /* jump_statement ::= RETURN expr_list SEMICOLON */
#line 1867 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-2].minor.yy0);
	stmt->Values = yymsp[-1].minor.yy138;
	yylhsminor.yy181 = stmt;
}
#line 5245 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy181 = yylhsminor.yy181;
        break;
      case 304: /* compound_statement ::= LBRACE RBRACE */
#line 1879 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy261 = stmt;
}
#line 5256 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-1].minor.yy261 = yylhsminor.yy261;
        break;
      case 305: /* compound_statement ::= LBRACE statement_list RBRACE */
#line 1885 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy181;
	yylhsminor.yy261 = stmt;
}
#line 5267 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy261 = yylhsminor.yy261;
        break;
      case 306: /* compound_statement ::= LBRACE error RBRACE */
#line 1891 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy261 = stmt;
}
#line 5278 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy261 = yylhsminor.yy261;
        break;
      case 309: /* expression_statement ::= expr */
#line 1911 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExpressionStmt, stmt, yymsp[0].minor.yy138);
	stmt->Expression = yymsp[0].minor.yy138;
	yylhsminor.yy420 = stmt;
}
#line 5289 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy420 = yylhsminor.yy420;
        break;
      case 310: /* iteration_statement ::= while_or_until LPAREN expr RPAREN statement */
#line 1923 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-4].minor.yy0);
	if (yymsp[-4].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-2].minor.yy138,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-2].minor.yy138;
	}
	iter->LoopStatement = yymsp[0].minor.yy181;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::Start;
	yylhsminor.yy181 = iter;
}
#line 5310 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy181 = yylhsminor.yy181;
        break;
      case 311: /* iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN */
#line 1941 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-5].minor.yy0);
	if (yymsp[-3].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-1].minor.yy138,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-1].minor.yy138;
	}
	iter->LoopStatement = yymsp[-4].minor.yy181;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::End;
	yylhsminor.yy181 = iter;
}
#line 5333 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy181 = yylhsminor.yy181;
        break;
      case 312: /* iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement */
#line 1959 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-8].minor.yy0);
	iter->LoopCondition = yymsp[-4].minor.yy138;
	iter->LoopStatement = yymsp[0].minor.yy181;
	iter->LoopBumper = yymsp[-2].minor.yy181;
	iter->CheckAt = ZCC_IterationStmt::Start;
	// The initialization expression appears outside the loop
	// for_init may be NULL if there is no initialization.
	SAFE_APPEND(yymsp[-6].minor.yy181, iter);
	// And the whole thing gets wrapped inside a compound statement in case the loop
	// initializer defined any variables.
	NEW_AST_NODE(CompoundStmt, wrap, yymsp[-8].minor.yy0);
	wrap->Content = yymsp[-6].minor.yy181;
	yylhsminor.yy181 = wrap;
}
#line 5355 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,49,&yymsp[-5].minor);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-8].minor.yy181 = yylhsminor.yy181;
        break;
      case 313: /* while_or_until ::= WHILE */
#line 1976 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_WHILE;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5368 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 314: /* while_or_until ::= UNTIL */
#line 1981 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_UNTIL;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5377 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 315: /* for_init ::= local_var */
#line 1987 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy388 /*X-overwrites-A*/; }
#line 5383 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 316: /* for_init ::= for_bump */
#line 1988 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy181 /*X-overwrites-A*/; }
#line 5388 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 317: /* for_bump ::= */
#line 1991 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy181 = NULL; }
#line 5393 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 318: /* for_bump ::= expression_statement */
#line 1992 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy420; /*X-overwrites-A*/ }
#line 5398 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 319: /* for_bump ::= for_bump COMMA expression_statement */
#line 1993 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy181 = yymsp[-2].minor.yy181; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy181, yymsp[0].minor.yy420); }
#line 5403 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 320: /* selection_statement ::= if_front */
#line 2007 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[0].minor.yy181 = yymsp[0].minor.yy167; /*X-overwrites-A*/
}
#line 5411 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
        break;
      case 321: /* selection_statement ::= if_front ELSE statement */
#line 2011 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy167->FalsePath = yymsp[0].minor.yy181;
	yymsp[-2].minor.yy181 = yymsp[-2].minor.yy167; /*X-overwrites-A*/
}
#line 5419 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,153,&yymsp[-1].minor);
        break;
      case 322: /* if_front ::= IF LPAREN expr RPAREN statement */
#line 2017 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IfStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy138;
	stmt->TruePath = yymsp[0].minor.yy181;
	stmt->FalsePath = NULL;
	yylhsminor.yy167 = stmt;
}
#line 5431 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy167 = yylhsminor.yy167;
        break;
      case 323: /* selection_statement ::= SWITCH LPAREN expr RPAREN statement */
#line 2028 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(SwitchStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy138;
	stmt->Content = yymsp[0].minor.yy181;
	yylhsminor.yy181 = stmt;
}
#line 5444 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy181 = yylhsminor.yy181;
        break;
      case 324: /* labeled_statement ::= CASE expr COLON */
#line 2040 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Condition = yymsp[-1].minor.yy138;
	yylhsminor.yy164 = stmt;
}
#line 5456 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-2].minor.yy164 = yylhsminor.yy164;
        break;
      case 325: /* labeled_statement ::= DEFAULT COLON */
#line 2046 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Condition = NULL;
	yylhsminor.yy164 = stmt;
}
#line 5467 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy164 = yylhsminor.yy164;
        break;
      case 326: /* assign_statement ::= LBRACKET expr_list RBRACKET EQ expr */
{  yy_destructor(yypParser,46,&yymsp[-4].minor);
#line 2059 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignStmt,stmt,yymsp[-3].minor.yy138);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy138;
	stmt->Sources = yymsp[0].minor.yy138;
	yymsp[-4].minor.yy453 = stmt;
}
#line 5481 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,115,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 327: /* local_var ::= type variable_list_with_init */
#line 2072 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(LocalVarStmt,vardef,yymsp[-1].minor.yy6);
	vardef->Type = yymsp[-1].minor.yy6;
	vardef->Vars = yymsp[0].minor.yy299;
	yylhsminor.yy388 = vardef;
}
#line 5494 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy388 = yylhsminor.yy388;
        break;
      case 328: /* var_init ::= IDENTIFIER */
#line 2081 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy299 = var;
}
#line 5507 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[0].minor.yy299 = yylhsminor.yy299;
        break;
      case 329: /* var_init ::= IDENTIFIER array_size */
#line 2091 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarInit,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy138;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy299 = var;
}
#line 5520 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yymsp[-1].minor.yy299 = yylhsminor.yy299;
        break;
      case 330: /* var_init ::= IDENTIFIER EQ expr */
#line 2101 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-2].minor.yy0);
	var->Name = ENamedName(yymsp[-2].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[0].minor.yy138;
	var->InitIsArray = false;
	yylhsminor.yy299 = var;
}
#line 5533 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy299 = yylhsminor.yy299;
        break;
      case 331: /* var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE */
#line 2111 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-4].minor.yy0);
	var->Name = ENamedName(yymsp[-4].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[-1].minor.yy138;
	var->InitIsArray = true;
	yylhsminor.yy299 = var;
}
#line 5547 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-4].minor.yy299 = yylhsminor.yy299;
        break;
      case 332: /* var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE */
#line 2121 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-5].minor.yy0);
	var->Name = ENamedName(yymsp[-5].minor.yy0.Int);
	var->ArraySize = yymsp[-4].minor.yy138;
	var->Init = yymsp[-1].minor.yy138;
	var->InitIsArray = true;
	yylhsminor.yy299 = var;
}
#line 5563 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy299 = yylhsminor.yy299;
        break;
      case 333: /* var_init ::= IDENTIFIER EQ LBRACE error RBRACE */
{  yy_destructor(yypParser,54,&yymsp[-4].minor);
#line 2131 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	yymsp[-4].minor.yy299 = NULL;
}
#line 5575 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 334: /* variable_list_with_init ::= variable_list_with_init COMMA var_init */
#line 2139 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy299, yymsp[0].minor.yy299);
	yymsp[-2].minor.yy299 = yymsp[-2].minor.yy299; /*X-overwrites-A*/
}
#line 5587 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 335: /* translation_unit ::= translation_unit EOF */
#line 178 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5594 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
        break;
      case 337: /* opt_semicolon ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 191 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5602 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 339: /* opt_comma ::= COMMA */
{  yy_destructor(yypParser,50,&yymsp[0].minor);
#line 194 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5610 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
}
        break;
      case 345: /* state_flow ::= state_flow_type scanner_mode SEMICOLON */
#line 650 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5617 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 355: /* primary ::= LPAREN error RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1330 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5625 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      default:
      /* (336) opt_semicolon ::= */ yytestcase(yyruleno==336);
      /* (338) opt_comma ::= */ yytestcase(yyruleno==338);
      /* (340) opt_expr ::= expr */ yytestcase(yyruleno==340);
      /* (341) opt_struct_body ::= struct_body */ yytestcase(yyruleno==341);
      /* (342) struct_body ::= struct_member */ yytestcase(yyruleno==342);
      /* (343) enum_list ::= enumerator */ yytestcase(yyruleno==343);
      /* (344) opt_enum_list ::= enum_list opt_comma */ yytestcase(yyruleno==344);
      /* (346) type_name1 ::= int_type */ yytestcase(yyruleno==346);
      /* (347) type_or_array ::= type */ yytestcase(yyruleno==347);
      /* (348) type_list ::= type_or_array */ yytestcase(yyruleno==348);
      /* (349) type_list_or_void ::= type_list */ yytestcase(yyruleno==349);
      /* (350) array_size ::= array_size_expr */ yytestcase(yyruleno==350);
      /* (351) variable_list ::= variable_name */ yytestcase(yyruleno==351);
      /* (352) opt_func_body ::= function_body */ yytestcase(yyruleno==352);
      /* (353) func_params ::= func_param_list */ yytestcase(yyruleno==353);
      /* (354) func_param_list ::= func_param */ yytestcase(yyruleno==354);
      /* (356) unary_expr ::= primary */ yytestcase(yyruleno==356);
      /* (357) expr ::= unary_expr */ yytestcase(yyruleno==357);
      /* (358) expr_list ::= expr */ yytestcase(yyruleno==358);
      /* (359) func_expr_list ::= func_expr_item */ yytestcase(yyruleno==359);
      /* (360) func_expr_item ::= named_expr */ yytestcase(yyruleno==360);
      /* (361) constant ::= string_constant */ yytestcase(yyruleno==361);
      /* (362) function_body ::= compound_statement */ yytestcase(yyruleno==362);
      /* (363) statement ::= selection_statement */ yytestcase(yyruleno==363);
      /* (364) statement ::= iteration_statement */ yytestcase(yyruleno==364);
      /* (365) statement ::= jump_statement */ yytestcase(yyruleno==365);
      /* (366) variable_list_with_init ::= var_init */ yytestcase(yyruleno==366);
       break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
#line 148 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
 /**failed = true;*/ 
#line 5700 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
/************ End %parse_failure code *****************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  ZCCParseTOKENTYPE yyminor         /* The minor type of the error token */
){
  ZCCParseARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 121 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"

	FString unexpected, expecting;

	int i;
	int stateno = yypParser->yytos->stateno;

	unexpected << "Unexpected " << ZCCTokenName(yymajor);

	// Determine all the terminals that the parser would have accepted at this point
	// (see yy_find_shift_action). This list can get quite long. Is it worthwhile to
	// print it when not debugging the grammar, or would that be too confusing to
	// the average user?
	if (stateno < YY_SHIFT_MAX && (i = yy_shift_ofst[stateno])!=YY_SHIFT_USE_DFLT)
	{
		for (int j = 1; j < YYERRORSYMBOL; ++j)
		{
			int k = i + j;
			if (k >= 0 && k < YY_ACTTAB_COUNT && yy_lookahead[k] == j)
			{
				expecting << (expecting.IsEmpty() ? "Expecting " : " or ") << ZCCTokenName(j);
			}
		}
	}
	stat->sc->ScriptMessage("%s\n%s\n", unexpected.GetChars(), expecting.GetChars());
	FScriptPosition::ErrorCounter++;
#line 5743 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
/************ End %syntax_error code ******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
#if 0
  assert( yypParser->yytos==yypParser->yystack );
#else
  while (yypParser->yytos>yypParser->yystack) yy_pop_parser_stack(yypParser);
#endif
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
#line 147 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/src/common/scripting/frontend/zcc-parse.lemon"
 DPrintf(DMSG_SPAMMY, "Input accepted\n"); 
#line 5774 "/home/abuild/rpmbuild/BUILD/gzdoom-g4.7.1/build/src/zcc-parse.c"
/*********** End %parse_accept code *******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ZCCParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ZCCParseTOKENTYPE yyminor       /* The value for the token */
  ZCCParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  ZCCParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
    fflush(yyTraceFILE);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
        fflush(yyTraceFILE);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
          fflush(yyTraceFILE);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
    fflush(yyTraceFILE);
  }
#endif
  return;
}
